@@ -18,10 +18,18 @@
 import abc
 import collections
 
-from oslo_log import log
+from keystoneclient.v2_0 import client as ksclient
+from oslo_config import cfg
+from oslo_context import context
 import oslo_messaging
 import six
-from stevedore import extension
+
+from ceilometer.i18n import _
+from ceilometer import messaging
+from ceilometer.openstack.common import log
+from ceilometer.publisher import utils
+
+cfg.CONF.import_group('service_credentials', 'ceilometer.service')
 
 LOG = log.getLogger(__name__)
 
@@ -29,6 +37,52 @@ ExchangeTopics = collections.namedtuple('ExchangeTopics',
                                         ['exchange', 'topics'])
 
 
+def _get_keystone():
+    try:
+        return ksclient.Client(
+            username=cfg.CONF.service_credentials.os_username,
+            password=cfg.CONF.service_credentials.os_password,
+            tenant_id=cfg.CONF.service_credentials.os_tenant_id,
+            tenant_name=cfg.CONF.service_credentials.os_tenant_name,
+            cacert=cfg.CONF.service_credentials.os_cacert,
+            auth_url=cfg.CONF.service_credentials.os_auth_url,
+            region_name=cfg.CONF.service_credentials.os_region_name,
+            insecure=cfg.CONF.service_credentials.insecure)
+    except Exception as e:
+        return e
+
+
+def check_keystone(service_type=None):
+    """Decorator function to check if manager has valid keystone client.
+
+       Also checks if the service is registered/enabled in Keystone.
+
+       :param service_type: name of service in Keystone
+    """
+    def wrapped(f):
+        def func(self, *args, **kwargs):
+            manager = kwargs.get('manager')
+            if not manager and len(args) > 0:
+                manager = args[0]
+            keystone = getattr(manager, 'keystone', None)
+            if not keystone:
+                keystone = _get_keystone()
+            if isinstance(keystone, Exception):
+                LOG.error(_('Skip due to keystone error %s'),
+                          keystone if keystone else '')
+                return iter([])
+            elif service_type:
+                endpoints = keystone.service_catalog.get_endpoints(
+                    service_type=service_type)
+                if not endpoints:
+                    LOG.warning(_('Skipping because %s service is not '
+                                  'registered in keystone') % service_type)
+                    return iter([])
+            return f(self, *args, **kwargs)
+        return func
+    return wrapped
+
+
 class PluginBase(object):
     """Base class for all plugins."""
 
@@ -36,20 +90,16 @@ class PluginBase(object):
 @six.add_metaclass(abc.ABCMeta)
 class NotificationBase(PluginBase):
     """Base class for plugins that support the notification API."""
-    def __init__(self, manager):
+    def __init__(self, transporter):
         super(NotificationBase, self).__init__()
         # NOTE(gordc): this is filter rule used by oslo.messaging to dispatch
         # messages to an endpoint.
-        if self.event_types:
-            self.filter_rule = oslo_messaging.NotificationFilter(
-                event_type='|'.join(self.event_types))
-        self.manager = manager
-
-    @staticmethod
-    def get_notification_topics(conf):
-        if 'notification_topics' in conf:
-            return conf.notification_topics
-        return conf.oslo_messaging_notifications.topics
+        self.filter_rule = oslo_messaging.NotificationFilter(
+            event_type='|'.join(self.event_types))
+        self.transporter = transporter
+        # NOTE(gordc): if no publisher, this isn't a PipelineManager and
+        # data should be requeued.
+        self.requeue = False if hasattr(transporter, 'publisher') else True
 
     @abc.abstractproperty
     def event_types(self):
@@ -58,7 +108,6 @@ class NotificationBase(PluginBase):
         Strings are defining the event types to be given to this plugin.
         """
 
-    @abc.abstractmethod
     def get_targets(self, conf):
         """Return a sequence of oslo.messaging.Target.
 
@@ -67,6 +116,18 @@ class NotificationBase(PluginBase):
         :param conf: Configuration.
         """
 
+        # TODO(sileht): Backwards compatibility, remove in J+2
+        if hasattr(self, 'get_exchange_topics'):
+            LOG.warn(_('get_exchange_topics API of NotificationPlugin is'
+                       'deprecated, implements get_targets instead.'))
+
+            targets = []
+            for exchange, topics in self.get_exchange_topics(conf):
+                targets.extend(oslo_messaging.Target(topic=topic,
+                                                     exchange=exchange)
+                               for topic in topics)
+            return targets
+
     @abc.abstractmethod
     def process_notification(self, message):
         """Return a sequence of Counter instances for the given message.
@@ -74,55 +135,53 @@ class NotificationBase(PluginBase):
         :param message: Message to process.
         """
 
-    @staticmethod
-    def _consume_and_drop(notifications):
-        """RPC endpoint for useless notification level"""
-        # NOTE(sileht): nothing special todo here, but because we listen
-        # for the generic notification exchange we have to consume all its
-        # queues
-
-    audit = _consume_and_drop
-    debug = _consume_and_drop
-    warn = _consume_and_drop
-    error = _consume_and_drop
-    critical = _consume_and_drop
-
-    def info(self, notifications):
-        """RPC endpoint for notification messages at info level
+    def info(self, ctxt, publisher_id, event_type, payload, metadata):
+        """RPC endpoint for notification messages
 
         When another service sends a notification over the message
         bus, this method receives it.
 
-        :param notifications: list of notifications
+        :param ctxt: oslo.messaging context
+        :param publisher_id: publisher of the notification
+        :param event_type: type of notification
+        :param payload: notification payload
+        :param metadata: metadata about the notification
+
         """
-        self._process_notifications('info', notifications)
+        notification = messaging.convert_to_old_notification_format(
+            'info', ctxt, publisher_id, event_type, payload, metadata)
+        self.to_samples_and_publish(context.get_admin_context(), notification)
 
-    def sample(self, notifications):
-        """RPC endpoint for notification messages at sample level
-
-        When another service sends a notification over the message
-        bus at sample priority, this method receives it.
-
-        :param notifications: list of notifications
-        """
-        self._process_notifications('sample', notifications)
-
-    def _process_notifications(self, priority, notifications):
-        for notification in notifications:
-            try:
-                self.to_samples_and_publish(notification)
-            except Exception:
-                LOG.error('Fail to process notification', exc_info=True)
-
-    def to_samples_and_publish(self, notification):
+    def to_samples_and_publish(self, context, notification):
         """Return samples produced by *process_notification*.
 
         Samples produced for the given notification.
         :param context: Execution context from the service or RPC call
         :param notification: The notification to process.
         """
-        with self.manager.publisher() as p:
-            p(list(self.process_notification(notification)))
+        if self.requeue:
+            meters = [
+                utils.meter_message_from_counter(
+                    sample, cfg.CONF.publisher.telemetry_secret)
+                for sample in self.process_notification(notification)
+            ]
+            for notifier in self.transporter:
+                notifier.sample(context.to_dict(),
+                                event_type='ceilometer.pipeline',
+                                payload=meters)
+        else:
+            with self.transporter.publisher(context) as p:
+                p(list(self.process_notification(notification)))
+
+
+class NonMetricNotificationBase(object):
+    """Use to mark non-measurement meters
+
+    There are a number of historical non-measurement meters that should really
+    be captured as events. This common base allows us to disable these invalid
+    meters.
+    """
+    pass
 
 
 class ExtensionLoadError(Exception):
@@ -136,7 +195,7 @@ class ExtensionLoadError(Exception):
 
 
 class PollsterPermanentError(Exception):
-    """Permanent error when polling.
+    """Permenant error when polling.
 
     When unrecoverable error happened in polling, pollster can raise this
     exception with failed resource to prevent itself from polling any more.
@@ -144,8 +203,8 @@ class PollsterPermanentError(Exception):
     error.
     """
 
-    def __init__(self, resources):
-        self.fail_res_list = resources
+    def __init__(self, resource):
+        self.fail_res = resource
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -160,9 +219,8 @@ class PollsterBase(PluginBase):
         """
         pass
 
-    def __init__(self, conf):
+    def __init__(self):
         super(PollsterBase, self).__init__()
-        self.conf = conf
         try:
             self.setup_environment()
         except Exception as err:
@@ -199,42 +257,9 @@ class PollsterBase(PluginBase):
 
         """
 
-    @classmethod
-    def build_pollsters(cls, conf):
-        """Return a list of tuple (name, pollster).
-
-        The name is the meter name which the pollster would return, the
-        pollster is a pollster object instance. The pollster which implements
-        this method should be registered in the namespace of
-        ceilometer.builder.xxx instead of ceilometer.poll.xxx.
-        """
-        return []
-
-    @classmethod
-    def get_pollsters_extensions(cls, conf):
-        """Return a list of stevedore extensions.
-
-        The returned stevedore extensions wrap the pollster object instances
-        returned by build_pollsters.
-        """
-        extensions = []
-        try:
-            for name, pollster in cls.build_pollsters(conf):
-                ext = extension.Extension(name, None, cls, pollster)
-                extensions.append(ext)
-        except Exception as err:
-            raise ExtensionLoadError(err)
-        return extensions
-
 
 @six.add_metaclass(abc.ABCMeta)
 class DiscoveryBase(object):
-    KEYSTONE_REQUIRED_FOR_SERVICE = None
-    """Service type required in keystone catalog to works"""
-
-    def __init__(self, conf):
-        self.conf = conf
-
     @abc.abstractmethod
     def discover(self, manager, param=None):
         """Discover resources to monitor.
@@ -257,7 +282,7 @@ class DiscoveryBase(object):
     def group_id(self):
         """Return group id of this discovery.
 
-        All running discoveries with the same group_id should return the same
+        All running recoveries with the same group_id should return the same
         set of resources at a given point in time. By default, a discovery is
         put into a global group, meaning that all discoveries of its type
         running anywhere in the cloud, return the same set of resources.
