@@ -17,16 +17,16 @@
 
 
 import abc
-import croniter
 import datetime
 
 from ceilometerclient import client as ceiloclient
-from oslo.config import cfg
-from oslo.utils import timeutils
+import croniter
+from oslo_config import cfg
+from oslo_utils import timeutils
 import pytz
 import six
 
-from ceilometer.openstack.common.gettextutils import _
+from ceilometer.i18n import _
 from ceilometer.openstack.common import log
 
 
@@ -102,6 +102,9 @@ class Evaluator(object):
             start_cron = croniter.croniter(tc['start'], now_tz)
             if cls._is_exact_match(start_cron, now_tz):
                 return True
+            # start_cron.cur has changed in _is_exact_match(),
+            # croniter cannot recover properly in some corner case.
+            start_cron = croniter.croniter(tc['start'], now_tz)
             latest_start = start_cron.get_prev(datetime.datetime)
             duration = datetime.timedelta(seconds=tc['duration'])
             if latest_start <= now_tz <= latest_start + duration:
