@@ -1,8 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 eNovance <licensing@enovance.com>
-#
-# Author: Julien Danjou <julien@danjou.info>
+# Copyright 2013 eNovance <licensing@enovance.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -17,6 +14,7 @@
 # under the License.
 
 import abc
+
 import six
 
 
@@ -25,11 +23,14 @@ class AlarmNotifier(object):
     """Base class for alarm notifier plugins."""
 
     @abc.abstractmethod
-    def notify(self, action, alarm_id, previous, current, reason, reason_data):
+    def notify(self, action, alarm_id, alarm_name, severity, previous,
+               current, reason, reason_data):
         """Notify that an alarm has been triggered.
 
         :param action: The action that is being attended, as a parsed URL.
         :param alarm_id: The triggered alarm.
+        :param alarm_name: The name of triggered alarm.
+        :param severity: The level of triggered alarm
         :param previous: The previous state of the alarm.
         :param current: The current state of the alarm.
         :param reason: The reason the alarm changed its state.
