@@ -1,8 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2013 eNovance
-#
-# Author: Julien Danjou <julien@danjou.info>
+# Copyright 2013 eNovance
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -18,7 +15,7 @@
 """Log alarm notifier."""
 
 from ceilometer.alarm import notifier
-from ceilometer.openstack.common.gettextutils import _  # noqa
+from ceilometer.i18n import _
 from ceilometer.openstack.common import log
 
 LOG = log.getLogger(__name__)
@@ -28,10 +25,15 @@ class LogAlarmNotifier(notifier.AlarmNotifier):
     "Log alarm notifier."""
 
     @staticmethod
-    def notify(action, alarm_id, previous, current, reason, reason_data):
+    def notify(action, alarm_id, alarm_name, severity, previous, current,
+               reason, reason_data):
         LOG.info(_(
-            "Notifying alarm %(alarm_id)s from %(previous)s "
-            "to %(current)s with action %(action)s because "
-            "%(reason)s") % ({'alarm_id': alarm_id, 'previous': previous,
-                              'current': current, 'action': action,
-                              'reason': reason}))
+            "Notifying alarm %(alarm_name)s %(alarm_id)s of %(severity)s "
+            "priority from %(previous)s to %(current)s with action %(action)s"
+            " because %(reason)s.") % ({'alarm_name': alarm_name,
+                                        'alarm_id': alarm_id,
+                                        'severity': severity,
+                                        'previous': previous,
+                                        'current': current,
+                                        'action': action,
+                                        'reason': reason}))
