@@ -21,18 +21,19 @@
 import json
 
 import jsonschema
-from oslo_log import log
 from oslo_utils import timeutils
 import pecan
 from pecan import rest
 from wsme import types as wtypes
 import wsmeext.pecan as wsme_pecan
 
+from ceilometer.alarm.storage import models as alarm_models
+from ceilometer.api.controllers.v2 import alarms
 from ceilometer.api.controllers.v2 import base
 from ceilometer.api.controllers.v2 import samples
-from ceilometer.api.controllers.v2 import utils as v2_utils
 from ceilometer.api import rbac
 from ceilometer.i18n import _
+from ceilometer.openstack.common import log
 from ceilometer import storage
 from ceilometer import utils
 
@@ -46,7 +47,7 @@ class ComplexQuery(base.Base):
     "The filter expression encoded in json."
 
     orderby = wtypes.text
-    "List of single-element dicts for specifying the ordering of the results."
+    "List of single-element dicts for specifing the ordering of the results."
 
     limit = int
     "The maximum number of results to be returned."
@@ -96,7 +97,7 @@ class ValidatedComplexQuery(object):
                              "project": "project_id"}
         self.name_mapping.update(additional_name_mapping)
         valid_keys = db_model.get_field_names()
-        valid_keys = list(valid_keys) + list(self.name_mapping.keys())
+        valid_keys = list(valid_keys) + self.name_mapping.keys()
         valid_fields = _list_to_regexp(valid_keys)
 
         if metadata_allowed:
@@ -200,7 +201,7 @@ class ValidatedComplexQuery(object):
                 self._validate_filter(self.filter_expr)
             except (ValueError, jsonschema.exceptions.ValidationError) as e:
                 raise base.ClientSideError(
-                    _("Filter expression not valid: %s") % e)
+                    _("Filter expression not valid: %s") % e.message)
             self._replace_isotime_with_datetime(self.filter_expr)
             self._convert_operator_to_lower_case(self.filter_expr)
             self._normalize_field_names_for_db_model(self.filter_expr)
@@ -215,14 +216,18 @@ class ValidatedComplexQuery(object):
                 self._validate_orderby(self.orderby)
             except (ValueError, jsonschema.exceptions.ValidationError) as e:
                 raise base.ClientSideError(
-                    _("Order-by expression not valid: %s") % e)
+                    _("Order-by expression not valid: %s") % e.message)
             self._convert_orderby_to_lower_case(self.orderby)
             self._normalize_field_names_in_orderby(self.orderby)
 
-        self.limit = (None if self.original_query.limit is wtypes.Unset
-                      else self.original_query.limit)
+        if self.original_query.limit is wtypes.Unset:
+            self.limit = None
+        else:
+            self.limit = self.original_query.limit
 
-        self.limit = v2_utils.enforce_limit(self.limit)
+        if self.limit is not None and self.limit <= 0:
+            msg = _('Limit should be positive')
+            raise base.ClientSideError(msg)
 
     @staticmethod
     def _convert_orderby_to_lower_case(orderby):
@@ -234,7 +239,7 @@ class ValidatedComplexQuery(object):
             self._replace_field_names(orderby_field)
 
     def _traverse_postorder(self, tree, visitor):
-        op = list(tree.keys())[0]
+        op = tree.keys()[0]
         if op.lower() in self.complex_operators:
             for i, operand in enumerate(tree[op]):
                 self._traverse_postorder(operand, visitor)
@@ -247,11 +252,12 @@ class ValidatedComplexQuery(object):
                                         visibility_field):
         """Do not allow other than own_project_id."""
         def check_project_id(subfilter):
-            op, value = list(subfilter.items())[0]
+            op = subfilter.keys()[0]
             if (op.lower() not in self.complex_operators
-                    and list(value.keys())[0] == visibility_field
-                    and value[visibility_field] != own_project_id):
-                raise base.ProjectNotAuthorized(value[visibility_field])
+                    and subfilter[op].keys()[0] == visibility_field
+                    and subfilter[op][visibility_field] != own_project_id):
+                raise base.ProjectNotAuthorized(
+                    subfilter[op][visibility_field])
 
         self._traverse_postorder(self.filter_expr, check_project_id)
 
@@ -277,25 +283,26 @@ class ValidatedComplexQuery(object):
 
     def _replace_isotime_with_datetime(self, filter_expr):
         def replace_isotime(subfilter):
-            op, value = list(subfilter.items())[0]
-            if op.lower() not in self.complex_operators:
-                field = list(value.keys())[0]
-                if field in self.timestamp_fields:
-                    date_time = self._convert_to_datetime(subfilter[op][field])
-                    subfilter[op][field] = date_time
+            op = subfilter.keys()[0]
+            if (op.lower() not in self.complex_operators
+                    and subfilter[op].keys()[0] in self.timestamp_fields):
+                field = subfilter[op].keys()[0]
+                date_time = self._convert_to_datetime(subfilter[op][field])
+                subfilter[op][field] = date_time
 
         self._traverse_postorder(filter_expr, replace_isotime)
 
     def _normalize_field_names_for_db_model(self, filter_expr):
         def _normalize_field_names(subfilter):
-            op, value = list(subfilter.items())[0]
+            op = subfilter.keys()[0]
             if op.lower() not in self.complex_operators:
-                self._replace_field_names(value)
+                self._replace_field_names(subfilter.values()[0])
         self._traverse_postorder(filter_expr,
                                  _normalize_field_names)
 
     def _replace_field_names(self, subfilter):
-        field, value = list(subfilter.items())[0]
+        field = subfilter.keys()[0]
+        value = subfilter[field]
         if field in self.name_mapping:
             del subfilter[field]
             subfilter[self.name_mapping[field]] = value
@@ -313,7 +320,7 @@ class ValidatedComplexQuery(object):
             date_time = date_time.replace(tzinfo=None)
             return date_time
         except ValueError:
-            LOG.exception("String %s is not a valid isotime" % isotime)
+            LOG.exception(_("String %s is not a valid isotime") % isotime)
             msg = _('Failed to parse the timestamp value %s') % isotime
             raise base.ClientSideError(msg)
 
@@ -354,6 +361,51 @@ class QuerySamplesController(rest.RestController):
                                             query.limit)]
 
 
+class QueryAlarmHistoryController(rest.RestController):
+    """Provides complex query possibilities for alarm history."""
+    @wsme_pecan.wsexpose([alarms.AlarmChange], body=ComplexQuery)
+    def post(self, body):
+        """Define query for retrieving AlarmChange data.
+
+        :param body: Query rules for the alarm history to be returned.
+        """
+
+        rbac.enforce('query_alarm_history', pecan.request)
+
+        query = ValidatedComplexQuery(body,
+                                      alarm_models.AlarmChange)
+        query.validate(visibility_field="on_behalf_of")
+        conn = pecan.request.alarm_storage_conn
+        return [alarms.AlarmChange.from_db_model(s)
+                for s in conn.query_alarm_history(query.filter_expr,
+                                                  query.orderby,
+                                                  query.limit)]
+
+
+class QueryAlarmsController(rest.RestController):
+    """Provides complex query possibilities for alarms."""
+    history = QueryAlarmHistoryController()
+
+    @wsme_pecan.wsexpose([alarms.Alarm], body=ComplexQuery)
+    def post(self, body):
+        """Define query for retrieving Alarm data.
+
+        :param body: Query rules for the alarms to be returned.
+        """
+
+        rbac.enforce('query_alarm', pecan.request)
+
+        query = ValidatedComplexQuery(body,
+                                      alarm_models.Alarm)
+        query.validate(visibility_field="project_id")
+        conn = pecan.request.alarm_storage_conn
+        return [alarms.Alarm.from_db_model(s)
+                for s in conn.query_alarms(query.filter_expr,
+                                           query.orderby,
+                                           query.limit)]
+
+
 class QueryController(rest.RestController):
 
     samples = QuerySamplesController()
+    alarms = QueryAlarmsController()
