@@ -20,9 +20,9 @@
 
 import copy
 import datetime
+import functools
 import inspect
 
-from oslo_log import log
 from oslo_utils import timeutils
 import pecan
 import six
@@ -30,24 +30,19 @@ import wsme
 
 from ceilometer.api.controllers.v2 import base
 from ceilometer.api import rbac
-from ceilometer.i18n import _
 from ceilometer import utils
 
-LOG = log.getLogger(__name__)
-
-
-def enforce_limit(limit):
-    """Ensure limit is defined and is valid. if not, set a default."""
-    if limit is None:
-        limit = pecan.request.cfg.api.default_api_return_limit
-        LOG.info('No limit value provided, result set will be'
-                 ' limited to %(limit)d.', {'limit': limit})
-    if not limit or limit <= 0:
-        raise base.ClientSideError(_("Limit must be positive"))
-    return limit
-
 
 def get_auth_project(on_behalf_of=None):
+    # when an alarm is created by an admin on behalf of another tenant
+    # we must ensure for:
+    # - threshold alarm, that an implicit query constraint on project_id is
+    #   added so that admin-level visibility on statistics is not leaked
+    # - combination alarm, that alarm ids verification is scoped to
+    #   alarms owned by the alarm project.
+    # hence for null auth_project (indicating admin-ness) we check if
+    # the creating tenant differs from the tenant on whose behalf the
+    # alarm is being created
     auth_project = rbac.get_limited_to_project(pecan.request.headers)
     created_by = pecan.request.headers.get('X-Project-Id')
     is_admin = auth_project is None
@@ -120,6 +115,9 @@ def validate_query(query, db_func, internal_keys=None,
     _verify_query_segregation(query)
 
     valid_keys = inspect.getargspec(db_func)[0]
+    if 'alarm_type' in valid_keys:
+        valid_keys.remove('alarm_type')
+        valid_keys.append('type')
 
     internal_timestamp_keys = ['end_timestamp', 'start_timestamp',
                                'end_timestamp_op', 'start_timestamp_op']
@@ -219,7 +217,8 @@ def query_to_kwargs(query, db_func, internal_keys=None,
     query = sanitize_query(query, db_func)
     translation = {'user_id': 'user',
                    'project_id': 'project',
-                   'resource_id': 'resource'}
+                   'resource_id': 'resource',
+                   'type': 'alarm_type'}
     stamp = {}
     metaquery = {}
     kwargs = {}
@@ -314,3 +313,25 @@ def flatten_metadata(metadata):
                                                          separator='.')
                     if type(v) is not set)
     return {}
+
+
+# TODO(fabiog): this decorator should disappear and have a more unified
+# way of controlling access and scope. Before messing with this, though
+# I feel this file should be re-factored in smaller chunks one for each
+# controller (e.g. meters, alarms and so on ...). Right now its size is
+# overwhelming.
+def requires_admin(func):
+
+    @functools.wraps(func)
+    def wrapped(*args, **kwargs):
+        usr_limit, proj_limit = rbac.get_limited_to(pecan.request.headers)
+        # If User and Project are None, you have full access.
+        if usr_limit and proj_limit:
+            # since this decorator get's called out of wsme context
+            # raising exception results internal error so call abort
+            # for handling the error
+            ex = base.ProjectNotAuthorized(proj_limit)
+            pecan.core.abort(status_code=ex.code, detail=ex.msg)
+        return func(*args, **kwargs)
+
+    return wrapped
