@@ -1,9 +1,6 @@
 #
 # Copyright 2012 New Dream Network, LLC (DreamHost)
 #
-# Author: Doug Hellmann <doug.hellmann@dreamhost.com>
-#         Angus Salkeld <asalkeld@redhat.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -18,10 +15,16 @@
 
 import threading
 
-from oslo.config import cfg
+from oslo_config import cfg
+
 from pecan import hooks
 
+from ceilometer.i18n import _LE
+from ceilometer.openstack.common import log
 from ceilometer import pipeline
+from ceilometer import storage
+
+LOG = log.getLogger(__name__)
 
 
 class ConfigHook(hooks.PecanHook):
@@ -30,20 +33,39 @@ class ConfigHook(hooks.PecanHook):
     That allows controllers to get it.
     """
 
-    def before(self, state):
+    @staticmethod
+    def before(state):
         state.request.cfg = cfg.CONF
 
 
 class DBHook(hooks.PecanHook):
 
-    def __init__(self, storage_connection, alarm_storage_connection):
-        self.storage_connection = storage_connection
-        self.alarm_storage_connection = alarm_storage_connection
+    def __init__(self):
+        self.storage_connection = DBHook.get_connection('metering')
+        self.event_storage_connection = DBHook.get_connection('event')
+        self.alarm_storage_connection = DBHook.get_connection('alarm')
+
+        if (not self.storage_connection and
+                not self.event_storage_connection and
+                not self.alarm_storage_connection):
+            raise Exception("Api failed to start. Failed to connect to "
+                            "databases, purpose:  %s" %
+                            ', '.join(['metering', 'event', 'alarm']))
 
     def before(self, state):
         state.request.storage_conn = self.storage_connection
+        state.request.event_storage_conn = self.event_storage_connection
         state.request.alarm_storage_conn = self.alarm_storage_connection
 
+    @staticmethod
+    def get_connection(purpose):
+        try:
+            return storage.get_connection_from_config(cfg.CONF, purpose)
+        except Exception as err:
+            params = {"purpose": purpose, "err": err}
+            LOG.exception(_LE("Failed to connect to db, purpose %(purpose)s "
+                              "retry later: %(err)s") % params)
+
 
 class PipelineHook(hooks.PecanHook):
     """Create and attach a pipeline to the request.
