@@ -1,8 +1,6 @@
 #
 # Copyright 2012 Red Hat, Inc
 #
-# Author: Eoghan Glynn <eglynn@redhat.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -17,23 +15,24 @@
 """Implementation of Inspector abstraction for libvirt."""
 
 from lxml import etree
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_utils import units
 import six
 
 from ceilometer.compute.pollsters import util
 from ceilometer.compute.virt import inspector as virt_inspector
-from ceilometer.openstack.common.gettextutils import _
+from ceilometer.i18n import _
 from ceilometer.openstack.common import log as logging
 
 libvirt = None
 
 LOG = logging.getLogger(__name__)
 
-libvirt_opts = [
+OPTS = [
     cfg.StrOpt('libvirt_type',
                default='kvm',
-               help='Libvirt domain type (valid options are: '
-                    'kvm, lxc, qemu, uml, xen).'),
+               choices=['kvm', 'lxc', 'qemu', 'uml', 'xen'],
+               help='Libvirt domain type.'),
     cfg.StrOpt('libvirt_uri',
                default='',
                help='Override the default libvirt URI '
@@ -41,7 +40,7 @@ libvirt_opts = [
 ]
 
 CONF = cfg.CONF
-CONF.register_opts(libvirt_opts)
+CONF.register_opts(OPTS)
 
 
 def retry_on_disconnect(function):
@@ -52,7 +51,7 @@ def retry_on_disconnect(function):
             if (e.get_error_code() == libvirt.VIR_ERR_SYSTEM_ERROR and
                 e.get_error_domain() in (libvirt.VIR_FROM_REMOTE,
                                          libvirt.VIR_FROM_RPC)):
-                LOG.debug('Connection to libvirt broken')
+                LOG.debug(_('Connection to libvirt broken'))
                 self.connection = None
                 return function(self, *args, **kwargs)
             else:
@@ -77,7 +76,7 @@ class LibvirtInspector(virt_inspector.Inspector):
             global libvirt
             if libvirt is None:
                 libvirt = __import__('libvirt')
-            LOG.debug('Connecting to libvirt: %s', self.uri)
+            LOG.debug(_('Connecting to libvirt: %s'), self.uri)
             self.connection = libvirt.openReadOnly(self.uri)
 
         return self.connection
@@ -95,48 +94,37 @@ class LibvirtInspector(virt_inspector.Inspector):
                 ex.get_error_domain() in (libvirt.VIR_FROM_REMOTE,
                                           libvirt.VIR_FROM_RPC)):
                 raise
-            msg = ("Error from libvirt while looking up instance Name "
-                   "%(instance_name)s UUID %(instance_uuid)s: "
-                   "[Error Code %(error_code)s] "
-                   "%(ex)s" % {'instance_name': instance_name,
-                               'instance_uuid': instance.id,
-                               'error_code': error_code,
-                               'ex': ex})
+            msg = _("Error from libvirt while looking up instance "
+                    "<name=%(name)s, id=%(id)s>: "
+                    "[Error Code %(error_code)s] "
+                    "%(ex)s") % {'name': instance_name,
+                                 'id': instance.id,
+                                 'error_code': error_code,
+                                 'ex': ex}
             raise virt_inspector.InstanceNotFoundException(msg)
 
-    @retry_on_disconnect
-    def inspect_instance(self, domain_id):
-        domain = self._get_connection().lookupByID(domain_id)
-        return virt_inspector.Instance(name=domain.name(),
-                                       UUID=domain.UUIDString())
-
-    @retry_on_disconnect
-    def inspect_instances(self):
-        if self._get_connection().numOfDomains() > 0:
-            for domain_id in self._get_connection().listDomainsID():
-                if domain_id != 0:
-                    try:
-                        yield self.inspect_instance(domain_id)
-                    except libvirt.libvirtError:
-                        # Instance was deleted while listing... ignore it
-                        pass
-
     def inspect_cpus(self, instance):
         domain = self._lookup_by_uuid(instance)
         dom_info = domain.info()
         return virt_inspector.CPUStats(number=dom_info[3], time=dom_info[4])
 
-    def inspect_vnics(self, instance):
+    def _get_domain_not_shut_off_or_raise(self, instance):
         instance_name = util.instance_name(instance)
         domain = self._lookup_by_uuid(instance)
+
         state = domain.info()[0]
         if state == libvirt.VIR_DOMAIN_SHUTOFF:
-            LOG.warn(_('Failed to inspect vnics of instance Name '
-                       '%(instance_name)s UUID %(instance_uuid)s, '
-                       'domain is in state of SHUTOFF'),
-                     {'instance_name': instance_name,
-                      'instance_uuid': instance.id})
-            return
+            msg = _('Failed to inspect data of instance '
+                    '<name=%(name)s, id=%(id)s>, '
+                    'domain state is SHUTOFF.') % {
+                'name': instance_name, 'id': instance.id}
+            raise virt_inspector.InstanceShutOffException(msg)
+
+        return domain
+
+    def inspect_vnics(self, instance):
+        domain = self._get_domain_not_shut_off_or_raise(instance)
+
         tree = etree.fromstring(domain.XMLDesc(0))
         for iface in tree.findall('devices/interface'):
             target = iface.find('target')
@@ -165,16 +153,8 @@ class LibvirtInspector(virt_inspector.Inspector):
             yield (interface, stats)
 
     def inspect_disks(self, instance):
-        instance_name = util.instance_name(instance)
-        domain = self._lookup_by_uuid(instance)
-        state = domain.info()[0]
-        if state == libvirt.VIR_DOMAIN_SHUTOFF:
-            LOG.warn(_('Failed to inspect disks of instance Name '
-                       '%(instance_name)s UUID %(instance_uuid)s, '
-                       'domain is in state of SHUTOFF'),
-                     {'instance_name': instance_name,
-                      'instance_uuid': instance.id})
-            return
+        domain = self._get_domain_not_shut_off_or_raise(instance)
+
         tree = etree.fromstring(domain.XMLDesc(0))
         for device in filter(
                 bool,
@@ -188,3 +168,52 @@ class LibvirtInspector(virt_inspector.Inspector):
                                              write_bytes=block_stats[3],
                                              errors=block_stats[4])
             yield (disk, stats)
+
+    def inspect_memory_usage(self, instance, duration=None):
+        instance_name = util.instance_name(instance)
+        domain = self._get_domain_not_shut_off_or_raise(instance)
+
+        try:
+            memory_stats = domain.memoryStats()
+            if (memory_stats and
+                    memory_stats.get('available') and
+                    memory_stats.get('unused')):
+                memory_used = (memory_stats.get('available') -
+                               memory_stats.get('unused'))
+                # Stat provided from libvirt is in KB, converting it to MB.
+                memory_used = memory_used / units.Ki
+                return virt_inspector.MemoryUsageStats(usage=memory_used)
+            else:
+                msg = _('Failed to inspect memory usage of instance '
+                        '<name=%(name)s, id=%(id)s>, '
+                        'can not get info from libvirt.') % {
+                    'name': instance_name, 'id': instance.id}
+                raise virt_inspector.NoDataException(msg)
+        # memoryStats might launch an exception if the method is not supported
+        # by the underlying hypervisor being used by libvirt.
+        except libvirt.libvirtError as e:
+            msg = _('Failed to inspect memory usage of %(instance_uuid)s, '
+                    'can not get info from libvirt: %(error)s') % {
+                'instance_uuid': instance.id, 'error': e}
+            raise virt_inspector.NoDataException(msg)
+
+    def inspect_disk_info(self, instance):
+        domain = self._get_domain_not_shut_off_or_raise(instance)
+
+        tree = etree.fromstring(domain.XMLDesc(0))
+        for device in filter(
+                bool,
+                [target.get("dev")
+                 for target in tree.findall('devices/disk/target')]):
+            disk = virt_inspector.Disk(device=device)
+            block_info = domain.blockInfo(device)
+            info = virt_inspector.DiskInfo(capacity=block_info[0],
+                                           allocation=block_info[1],
+                                           physical=block_info[2])
+
+            yield (disk, info)
+
+    def inspect_memory_resident(self, instance, duration=None):
+        domain = self._get_domain_not_shut_off_or_raise(instance)
+        memory = domain.memoryStats()['rss'] / units.Ki
+        return virt_inspector.MemoryResidentStats(resident=memory)
