@@ -1,8 +1,6 @@
 #
 # Copyright 2013 IBM Corp
 #
-# Author: Tong Li <litong01@us.ibm.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -18,11 +16,11 @@
 import logging
 import logging.handlers
 
-from oslo.config import cfg
+from oslo_config import cfg
 
 from ceilometer import dispatcher
 
-file_dispatcher_opts = [
+OPTS = [
     cfg.StrOpt('file_path',
                help='Name and the location of the file to record '
                     'meters.'),
@@ -34,7 +32,7 @@ file_dispatcher_opts = [
                help='The max number of the files to keep.'),
 ]
 
-cfg.CONF.register_opts(file_dispatcher_opts, group="dispatcher_file")
+cfg.CONF.register_opts(OPTS, group="dispatcher_file")
 
 
 class FileDispatcher(dispatcher.Base):
