@@ -11,10 +11,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo.config import cfg
 import oslo.messaging
+from oslo_config import cfg
 
-from ceilometer import plugin
+from ceilometer.agent import plugin_base
 from ceilometer import sample
 
 OPTS = [
@@ -29,7 +29,8 @@ cfg.CONF.register_opts(OPTS)
 SERVICE = 'identity'
 
 
-class _Base(plugin.NotificationBase):
+class _Base(plugin_base.NotificationBase,
+            plugin_base.NonMetricNotificationBase):
     """Convert identity notification into Samples."""
 
     resource_type = None
@@ -49,13 +50,14 @@ class _Base(plugin.NotificationBase):
 
 class IdentityCRUD(_Base):
     def process_notification(self, message):
+        user_id = message['payload'].get("initiator", {}).get("id")
         yield sample.Sample.from_notification(
             name=message['event_type'],
             type=sample.TYPE_DELTA,
             unit=self.resource_type,
             volume=1,
             resource_id=message['payload']['resource_info'],
-            user_id=None,
+            user_id=user_id,
             project_id=None,
             message=message)
 
@@ -97,10 +99,10 @@ class Role(IdentityCRUD):
 
     @property
     def event_types(self):
-        return ['%s.*' % self.resource_name]
+        return ['%s\..*' % self.resource_name]
 
 
-class Trust(IdentityCRUD):
+class Trust(_Base):
 
     resource_type = 'OS-TRUST:trust'
     resource_name = '%s.%s' % (SERVICE, resource_type)
@@ -112,6 +114,19 @@ class Trust(IdentityCRUD):
             '%s.deleted' % self.resource_name,
         ]
 
+    def process_notification(self, message):
+        name = message['event_type'].replace(self.resource_type, 'trust')
+        user_id = message['payload'].get("initiator", {}).get("id")
+        yield sample.Sample.from_notification(
+            name=name,
+            type=sample.TYPE_DELTA,
+            unit='trust',
+            volume=1,
+            resource_id=message['payload']['resource_info'],
+            user_id=user_id,
+            project_id=None,
+            message=message)
+
 
 class Authenticate(_Base):
     """Convert identity authentication notifications into Samples."""
@@ -136,3 +151,35 @@ class Authenticate(_Base):
     @property
     def event_types(self):
         return [self.event_name]
+
+
+class RoleAssignment(_Base):
+    """Convert role assignment notifications into Samples."""
+
+    resource_type = 'role_assignment'
+    resource_name = '%s.%s' % (SERVICE, resource_type)
+
+    def process_notification(self, message):
+        # NOTE(stevemar): action is created.role_assignment
+        action = message['payload']['action']
+        event, resource_type = action.split(".")
+
+        # NOTE(stevemar): meter_name is identity.role_assignment.created
+        meter_name = '%s.%s.%s' % (SERVICE, resource_type, event)
+
+        yield sample.Sample.from_notification(
+            name=meter_name,
+            type=sample.TYPE_DELTA,
+            unit=self.resource_type,
+            volume=1,
+            resource_id=message['payload']['role'],
+            user_id=message['payload']['initiator']['id'],
+            project_id=None,
+            message=message)
+
+    @property
+    def event_types(self):
+        return [
+            '%s.created' % self.resource_name,
+            '%s.deleted' % self.resource_name,
+        ]
