@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright 2013 eNovance <licensing@enovance.com>
 #
-# Author: Mehdi Abaakouk <mehdi.abaakouk@enovance.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -15,11 +13,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo.config import cfg
 import oslo.messaging
-from oslo.serialization import jsonutils
-
-from ceilometer.openstack.common import context
+from oslo_config import cfg
+from oslo_context import context
+from oslo_serialization import jsonutils
 
 DEFAULT_URL = "__default__"
 TRANSPORTS = {}
@@ -104,12 +101,13 @@ def get_rpc_server(transport, topic, endpoint):
                                          serializer=serializer)
 
 
-def get_rpc_client(transport, **kwargs):
+def get_rpc_client(transport, retry=None, **kwargs):
     """Return a configured oslo.messaging RPCClient."""
     target = oslo.messaging.Target(**kwargs)
     serializer = RequestContextSerializer(JsonPayloadSerializer())
     return oslo.messaging.RPCClient(transport, target,
-                                    serializer=serializer)
+                                    serializer=serializer,
+                                    retry=retry)
 
 
 def get_notification_listener(transport, targets, endpoints,
