@@ -1,8 +1,6 @@
 #
 # Copyright 2014 Cisco Systems,Inc.
 #
-# Author: Pradeep Kilambi <pkilambi@cisco.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -14,10 +12,10 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo.utils import timeutils
+from oslo_utils import timeutils
 
+from ceilometer.i18n import _
 from ceilometer.network.services import base
-from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log
 from ceilometer import sample
 
@@ -88,7 +86,7 @@ class FirewallPolicyPollster(base.BaseServicesPollster):
             yield sample.Sample(
                 name='network.services.firewall.policy',
                 type=sample.TYPE_GAUGE,
-                unit='policy',
+                unit='firewall_policy',
                 volume=1,
                 user_id=None,
                 project_id=fw['tenant_id'],
