@@ -1,8 +1,6 @@
 #
 # Copyright 2014 Cisco Systems,Inc.
 #
-# Author: Pradeep Kilambi <pkilambi@cisco.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -18,11 +16,11 @@
 import abc
 import collections
 
-from oslo.utils import timeutils
+from oslo_utils import timeutils
 import six
 
+from ceilometer.i18n import _
 from ceilometer.network.services import base
-from ceilometer.openstack.common.gettextutils import _
 from ceilometer.openstack.common import log
 from ceilometer import sample
 
@@ -188,7 +186,7 @@ class LBHealthMonitorPollster(base.BaseServicesPollster):
             yield sample.Sample(
                 name='network.services.lb.health_monitor',
                 type=sample.TYPE_GAUGE,
-                unit='monitor',
+                unit='health_monitor',
                 volume=1,
                 user_id=None,
                 project_id=probe['tenant_id'],
@@ -281,7 +279,7 @@ class LBTotalConnectionsPollster(_LBStatsPollster):
         return make_sample_from_pool(
             pool,
             name='network.services.lb.total.connections',
-            type=sample.TYPE_GAUGE,
+            type=sample.TYPE_CUMULATIVE,
             unit='connection',
             volume=data.total_connections,
         )
