@@ -1,6 +1,4 @@
 #
-# Author: John Tran <jhtran@att.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -16,27 +14,27 @@
 import functools
 
 import novaclient
-from novaclient.v1_1 import client as nova_client
-from oslo.config import cfg
+from novaclient import client as nova_client
+from oslo_config import cfg
 
 from ceilometer.openstack.common import log
 
 
-nova_opts = [
+OPTS = [
     cfg.BoolOpt('nova_http_log_debug',
                 default=False,
                 help='Allow novaclient\'s debug log output.'),
 ]
 
-service_types_opts = [
+SERVICE_OPTS = [
     cfg.StrOpt('nova',
                default='compute',
                help='Nova service type.'),
 ]
 
-cfg.CONF.register_opts(nova_opts)
-cfg.CONF.register_opts(service_types_opts, group='service_types')
-
+cfg.CONF.register_opts(OPTS)
+cfg.CONF.register_opts(SERVICE_OPTS, group='service_types')
+cfg.CONF.import_opt('http_timeout', 'ceilometer.service')
 cfg.CONF.import_group('service_credentials', 'ceilometer.service')
 
 LOG = log.getLogger(__name__)
@@ -63,6 +61,7 @@ class Client(object):
         conf = cfg.CONF.service_credentials
         tenant = conf.os_tenant_id or conf.os_tenant_name
         self.nova_client = nova_client.Client(
+            version=2,
             username=conf.os_username,
             api_key=conf.os_password,
             project_id=tenant,
@@ -74,6 +73,7 @@ class Client(object):
             bypass_url=bypass_url,
             cacert=conf.os_cacert,
             insecure=conf.insecure,
+            timeout=cfg.CONF.http_timeout,
             http_log_debug=cfg.CONF.nova_http_log_debug,
             no_cache=True)
 
@@ -137,17 +137,29 @@ class Client(object):
             setattr(instance, attr, ameta)
 
     @logged
-    def instance_get_all_by_host(self, hostname):
-        """Returns list of instances on particular host."""
+    def instance_get_all_by_host(self, hostname, since=None):
+        """Returns list of instances on particular host.
+
+        If since is supplied, it will return the instances changed since that
+        datetime. since should be in ISO Format '%Y-%m-%dT%H:%M:%SZ'
+        """
         search_opts = {'host': hostname, 'all_tenants': True}
+        if since:
+            search_opts['changes-since'] = since
         return self._with_flavor_and_image(self.nova_client.servers.list(
             detailed=True,
             search_opts=search_opts))
 
     @logged
-    def instance_get_all(self):
-        """Returns list of all instances."""
+    def instance_get_all(self, since=None):
+        """Returns list of all instances.
+
+        If since is supplied, it will return the instances changes since that
+        datetime. since should be in ISO Format '%Y-%m-%dT%H:%M:%SZ'
+        """
         search_opts = {'all_tenants': True}
+        if since:
+            search_opts['changes-since'] = since
         return self.nova_client.servers.list(
             detailed=True,
             search_opts=search_opts)
