@@ -15,19 +15,22 @@
 """Common code for working with ceph object stores
 """
 
-from keystoneauth1 import exceptions
+from keystoneclient import exceptions
 from oslo_config import cfg
-from oslo_log import log
+from oslo_utils import timeutils
 import six.moves.urllib.parse as urlparse
 
-from ceilometer import keystone_client
-from ceilometer.polling import plugin_base
+from ceilometer.agent import plugin_base
+from ceilometer.i18n import _
+from ceilometer.objectstore.rgw_client import RGWAdminClient as rgwclient
+from ceilometer.openstack.common import log
 from ceilometer import sample
 
 LOG = log.getLogger(__name__)
 
 SERVICE_OPTS = [
     cfg.StrOpt('radosgw',
+               default='object-store',
                help='Radosgw service type.'),
 ]
 
@@ -40,22 +43,18 @@ CREDENTIAL_OPTS = [
                help='Secret key for Radosgw Admin.')
 ]
 
-CLIENT_OPTS = [
-    cfg.BoolOpt('implicit_tenants',
-                default=False,
-                help='Whether RGW uses implicit tenants or not.'),
-]
+cfg.CONF.register_opts(SERVICE_OPTS, group='service_types')
+cfg.CONF.register_opts(CREDENTIAL_OPTS, group='rgw_admin_credentials')
+cfg.CONF.import_group('rgw_admin_credentials', 'ceilometer.service')
 
 
 class _Base(plugin_base.PollsterBase):
     METHOD = 'bucket'
     _ENDPOINT = None
 
-    def __init__(self, conf):
-        super(_Base, self).__init__(conf)
-        self.access_key = self.conf.rgw_admin_credentials.access_key
-        self.secret = self.conf.rgw_admin_credentials.secret_key
-        self.implicit_tenants = self.conf.rgw_client.implicit_tenants
+    def __init__(self):
+        self.access_key = cfg.CONF.rgw_admin_credentials.access_key
+        self.secret = cfg.CONF.rgw_admin_credentials.secret_key
 
     @property
     def default_discovery(self):
@@ -66,21 +65,19 @@ class _Base(plugin_base.PollsterBase):
         return 'rgw.get_%s' % self.METHOD
 
     @staticmethod
-    def _get_endpoint(conf, ksclient):
+    def _get_endpoint(ksclient):
         # we store the endpoint as a base class attribute, so keystone is
         # only ever called once, also we assume that in a single deployment
         # we may be only deploying `radosgw` or `swift` as the object-store
-        if _Base._ENDPOINT is None and conf.service_types.radosgw:
+        if _Base._ENDPOINT is None:
             try:
-                creds = conf.service_credentials
-                rgw_url = keystone_client.get_service_catalog(
-                    ksclient).url_for(
-                        service_type=conf.service_types.radosgw,
-                        interface=creds.interface,
-                        region_name=creds.region_name)
+                conf = cfg.CONF.service_credentials
+                rgw_url = ksclient.service_catalog.url_for(
+                    service_type=cfg.CONF.service_types.radosgw,
+                    endpoint_type=conf.os_endpoint_type)
                 _Base._ENDPOINT = urlparse.urljoin(rgw_url, '/admin')
             except exceptions.EndpointNotFound:
-                LOG.debug("Radosgw endpoint not found")
+                LOG.debug(_("Radosgw endpoint not found"))
         return _Base._ENDPOINT
 
     def _iter_accounts(self, ksclient, cache, tenants):
@@ -90,19 +87,11 @@ class _Base(plugin_base.PollsterBase):
         return iter(cache[self.CACHE_KEY_METHOD])
 
     def _get_account_info(self, ksclient, tenants):
-        endpoint = self._get_endpoint(self.conf, ksclient)
+        endpoint = self._get_endpoint(ksclient)
         if not endpoint:
-            return
-
-        try:
-            from ceilometer.objectstore import rgw_client as c_rgw_client
-            rgw_client = c_rgw_client.RGWAdminClient(endpoint,
-                                                     self.access_key,
-                                                     self.secret,
-                                                     self.implicit_tenants)
-        except ImportError:
-            raise plugin_base.PollsterPermanentError(tenants)
+            raise StopIteration()
 
+        rgw_client = rgwclient(endpoint, self.access_key, self.secret)
         for t in tenants:
             api_method = 'get_%s' % self.METHOD
             yield t.id, getattr(rgw_client, api_method)(t.id)
@@ -123,6 +112,7 @@ class ContainersObjectsPollster(_Base):
                     user_id=None,
                     project_id=tenant,
                     resource_id=tenant + '/' + it.name,
+                    timestamp=timeutils.isotime(),
                     resource_metadata=None,
                 )
 
@@ -134,16 +124,17 @@ class ContainersSizePollster(_Base):
         for tenant, bucket_info in self._iter_accounts(manager.keystone,
                                                        cache, resources):
             for it in bucket_info['buckets']:
-                yield sample.Sample(
-                    name='radosgw.containers.objects.size',
-                    type=sample.TYPE_GAUGE,
-                    volume=int(it.size * 1024),
-                    unit='B',
-                    user_id=None,
-                    project_id=tenant,
-                    resource_id=tenant + '/' + it.name,
-                    resource_metadata=None,
-                )
+                    yield sample.Sample(
+                        name='radosgw.containers.objects.size',
+                        type=sample.TYPE_GAUGE,
+                        volume=int(it.size * 1024),
+                        unit='B',
+                        user_id=None,
+                        project_id=tenant,
+                        resource_id=tenant + '/' + it.name,
+                        timestamp=timeutils.isotime(),
+                        resource_metadata=None,
+                    )
 
 
 class ObjectsSizePollster(_Base):
@@ -160,6 +151,7 @@ class ObjectsSizePollster(_Base):
                 user_id=None,
                 project_id=tenant,
                 resource_id=tenant,
+                timestamp=timeutils.isotime(),
                 resource_metadata=None,
                 )
 
@@ -178,6 +170,7 @@ class ObjectsPollster(_Base):
                 user_id=None,
                 project_id=tenant,
                 resource_id=tenant,
+                timestamp=timeutils.isotime(),
                 resource_metadata=None,
                 )
 
@@ -194,6 +187,7 @@ class ObjectsContainersPollster(_Base):
                 user_id=None,
                 project_id=tenant,
                 resource_id=tenant,
+                timestamp=timeutils.isotime(),
                 resource_metadata=None,
                 )
 
@@ -213,5 +207,6 @@ class UsagePollster(_Base):
                 user_id=None,
                 project_id=tenant,
                 resource_id=tenant,
+                timestamp=timeutils.isotime(),
                 resource_metadata=None,
                 )
