@@ -1,8 +1,6 @@
 #
 # Copyright 2012 eNovance
 #
-# Author: Guillaume Pernot <gpernot@praksys.org>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -20,13 +18,13 @@
 from __future__ import absolute_import
 
 from keystoneclient import exceptions
-from oslo.config import cfg
-from oslo.utils import timeutils
+from oslo_config import cfg
+from oslo_utils import timeutils
 import six.moves.urllib.parse as urlparse
 from swiftclient import client as swift
 
-from ceilometer.central import plugin
-from ceilometer.openstack.common.gettextutils import _
+from ceilometer.agent import plugin_base
+from ceilometer.i18n import _
 from ceilometer.openstack.common import log
 from ceilometer import sample
 
@@ -40,17 +38,18 @@ OPTS = [
                "reseller_prefix in proxy-server.conf."),
 ]
 
-service_types_opts = [
+SERVICE_OPTS = [
     cfg.StrOpt('swift',
                default='object-store',
                help='Swift service type.'),
 ]
 
 cfg.CONF.register_opts(OPTS)
-cfg.CONF.register_opts(service_types_opts, group='service_types')
+cfg.CONF.register_opts(SERVICE_OPTS, group='service_types')
+cfg.CONF.import_group('service_credentials', 'ceilometer.service')
 
 
-class _Base(plugin.CentralPollster):
+class _Base(plugin_base.PollsterBase):
 
     METHOD = 'head'
     _ENDPOINT = None
