@@ -1,5 +1,3 @@
-# Author: Swann Croiset <swann.croiset@bull.net>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -15,10 +13,10 @@
    events.
 """
 
-from oslo.config import cfg
 import oslo.messaging
+from oslo_config import cfg
 
-from ceilometer import plugin
+from ceilometer.agent import plugin_base
 from ceilometer import sample
 
 
@@ -32,7 +30,8 @@ cfg.CONF.register_opts(OPTS)
 SERVICE = 'orchestration'
 
 
-class StackCRUD(plugin.NotificationBase):
+class StackCRUD(plugin_base.NotificationBase,
+                plugin_base.NonMetricNotificationBase):
 
     resource_name = '%s.stack' % SERVICE
 
