@@ -13,6 +13,8 @@
 """HBase storage backend migrations
 """
 
+import re
+
 from ceilometer.storage.hbase import utils as hbase_utils
 
 
@@ -62,8 +64,51 @@ def migrate_meter_table(conn, table):
         meter_table.delete(row)
 
 
+def migrate_event_table(conn, table):
+    """Migrate table 'event' in HBase.
+
+    Change row format from ""%d_%s" % timestamp, event_id,
+    to new separator format "%s:%s" % timestamp, event_id
+    Also change trait columns from %s+%s % trait.name, trait.dtype
+    to %s:%s % trait.name, trait.dtype
+    """
+    event_table = conn.table(table)
+    event_filter = "RowFilter(=, 'regexstring:\\d*_\\w*')"
+    gen = event_table.scan(filter=event_filter)
+    trait_pattern = re.compile("f:[\w\-_]*\+\w")
+    column_prefix = "f:"
+    for row, data in gen:
+        row_parts = row.split("_", 1)
+        update_data = {}
+        for column, value in data.items():
+            if trait_pattern.match(column):
+                trait_parts = column[2:].rsplit('+', 1)
+                column = hbase_utils.prepare_key(*trait_parts)
+            update_data[column_prefix + column] = value
+        new_row = hbase_utils.prepare_key(*row_parts)
+        event_table.put(new_row, update_data)
+        event_table.delete(row)
+
+
+def migrate_alarm_history_table(conn, table):
+    """Migrate table 'alarm_h' in HBase.
+
+    Change row format from ""%s_%s" % alarm_id, rts,
+    to new separator format "%s:%s" % alarm_id, rts
+    """
+    alarm_h_table = conn.table(table)
+    alarm_h_filter = "RowFilter(=, 'regexstring:\\w*_\\d{19}')"
+    gen = alarm_h_table.scan(filter=alarm_h_filter)
+    for row, data in gen:
+        row_parts = row.rsplit('_', 1)
+        alarm_h_table.put(hbase_utils.prepare_key(*row_parts), data)
+        alarm_h_table.delete(row)
+
+
 TABLE_MIGRATION_FUNCS = {'resource': migrate_resource_table,
-                         'meter': migrate_meter_table}
+                         'alarm_h': migrate_alarm_history_table,
+                         'meter': migrate_meter_table,
+                         'event': migrate_event_table}
 
 
 def migrate_tables(conn, tables):
