@@ -1,6 +1,3 @@
-#
-# Author: John Tran <jhtran@att.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -19,20 +16,18 @@ SQLAlchemy models for Ceilometer data.
 import hashlib
 import json
 
-from oslo.utils import timeutils
+from oslo_utils import timeutils
 import six
 from sqlalchemy import (Column, Integer, String, ForeignKey, Index,
                         UniqueConstraint, BigInteger)
-from sqlalchemy import event, select
+from sqlalchemy import event
 from sqlalchemy import Float, Boolean, Text, DateTime
 from sqlalchemy.dialects.mysql import DECIMAL
 from sqlalchemy.ext.declarative import declarative_base
-from sqlalchemy.orm import backref
 from sqlalchemy.orm import deferred
 from sqlalchemy.orm import relationship
 from sqlalchemy.types import TypeDecorator
 
-from ceilometer.storage import models as api_models
 from ceilometer import utils
 
 
@@ -41,12 +36,14 @@ class JSONEncodedDict(TypeDecorator):
 
     impl = String
 
-    def process_bind_param(self, value, dialect):
+    @staticmethod
+    def process_bind_param(value, dialect):
         if value is not None:
             value = json.dumps(value)
         return value
 
-    def process_result_value(self, value, dialect):
+    @staticmethod
+    def process_result_value(value, dialect):
         if value is not None:
             value = json.loads(value)
         return value
@@ -64,14 +61,16 @@ class PreciseTimestamp(TypeDecorator):
                                                    asdecimal=True))
         return self.impl
 
-    def process_bind_param(self, value, dialect):
+    @staticmethod
+    def process_bind_param(value, dialect):
         if value is None:
             return value
         elif dialect.name == 'mysql':
             return utils.dt_to_decimal(value)
         return value
 
-    def process_result_value(self, value, dialect):
+    @staticmethod
+    def process_result_value(value, dialect):
         if value is None:
             return value
         elif dialect.name == 'mysql':
@@ -222,29 +221,23 @@ class Sample(Base):
     message_id = Column(String(1000))
 
 
-class FullSample(Base):
-    """Mapper model.
-
-    It's needed as many of the filters work against raw data which is split
-    between Meter, Sample, and Resource tables
-    """
-    meter = Meter.__table__
-    sample = Sample.__table__
-    resource = Resource.__table__
-    __table__ = (select([sample.c.id, meter.c.name.label('counter_name'),
-                         meter.c.type.label('counter_type'),
-                         meter.c.unit.label('counter_unit'),
-                         sample.c.volume.label('counter_volume'),
-                         resource.c.resource_id, resource.c.source_id,
-                         resource.c.user_id, resource.c.project_id,
-                         resource.c.resource_metadata, resource.c.internal_id,
-                         sample.c.timestamp, sample.c.message_id,
-                         sample.c.message_signature, sample.c.recorded_at])
-                 .select_from(
-                     sample.join(meter, sample.c.meter_id == meter.c.id).join(
-                         resource,
-                         sample.c.resource_id == resource.c.internal_id))
-                 .alias())
+class FullSample(object):
+    """A fake model for query samples."""
+    id = Sample.id
+    timestamp = Sample.timestamp
+    message_id = Sample.message_id
+    message_signature = Sample.message_signature
+    recorded_at = Sample.recorded_at
+    counter_name = Meter.name
+    counter_type = Meter.type
+    counter_unit = Meter.unit
+    counter_volume = Sample.volume
+    resource_id = Resource.resource_id
+    source_id = Resource.source_id
+    user_id = Resource.user_id
+    project_id = Resource.project_id
+    resource_metadata = Resource.resource_metadata
+    internal_id = Resource.internal_id
 
 
 class Alarm(Base):
@@ -258,6 +251,7 @@ class Alarm(Base):
     enabled = Column(Boolean)
     name = Column(Text)
     type = Column(String(50))
+    severity = Column(String(50))
     description = Column(Text)
     timestamp = Column(PreciseTimestamp, default=lambda: timeutils.utcnow())
 
@@ -317,14 +311,16 @@ class Event(Base):
     id = Column(Integer, primary_key=True)
     message_id = Column(String(50), unique=True)
     generated = Column(PreciseTimestamp())
+    raw = deferred(Column(JSONEncodedDict()))
 
     event_type_id = Column(Integer, ForeignKey('event_type.id'))
     event_type = relationship("EventType", backref='events')
 
-    def __init__(self, message_id, event_type, generated):
+    def __init__(self, message_id, event_type, generated, raw):
         self.message_id = message_id
         self.event_type = event_type
         self.generated = generated
+        self.raw = raw
 
     def __repr__(self):
         return "<Event %d('Event: %s %s, Generated: %s')>" % (self.id,
@@ -333,93 +329,49 @@ class Event(Base):
                                                               self.generated)
 
 
-class TraitType(Base):
-    """Types of event traits.
+class TraitText(Base):
+    """Event text traits."""
 
-    A trait type includes a description and a data type. Uniqueness is
-    enforced compositely on the data_type and desc fields. This is to
-    accommodate cases, such as 'generated', which, depending on the
-    corresponding event, could be a date, a boolean, or a float.
-    """
-    __tablename__ = 'trait_type'
+    __tablename__ = 'trait_text'
     __table_args__ = (
-        UniqueConstraint('desc', 'data_type', name='tt_unique'),
-        Index('ix_trait_type', 'desc')
+        Index('ix_trait_text_event_id_key', 'event_id', 'key'),
     )
-
-    id = Column(Integer, primary_key=True)
-    desc = Column(String(255))
-    data_type = Column(Integer)
-
-    def __init__(self, desc, data_type):
-        self.desc = desc
-        self.data_type = data_type
-
-    def __repr__(self):
-        return "<TraitType: %s:%d>" % (self.desc, self.data_type)
+    event_id = Column(Integer, ForeignKey('event.id'), primary_key=True)
+    key = Column(Integer, primary_key=True)
+    value = Column(Text)
 
 
-class Trait(Base):
-    __tablename__ = 'trait'
+class TraitInt(Base):
+    """Event integer traits."""
+
+    __tablename__ = 'trait_int'
     __table_args__ = (
-        Index('ix_trait_t_int', 't_int'),
-        Index('ix_trait_t_string', 't_string'),
-        Index('ix_trait_t_datetime', 't_datetime'),
-        Index('ix_trait_t_float', 't_float'),
+        Index('ix_trait_int_event_id_key', 'event_id', 'key'),
     )
-    id = Column(Integer, primary_key=True)
+    event_id = Column(Integer, ForeignKey('event.id'), primary_key=True)
+    key = Column(Integer, primary_key=True)
+    value = Column(Integer)
 
-    trait_type_id = Column(Integer, ForeignKey('trait_type.id'))
-    trait_type = relationship("TraitType", backref='traits')
 
-    t_string = Column(String(255), nullable=True, default=None)
-    t_float = Column(Float(53), nullable=True, default=None)
-    t_int = Column(Integer, nullable=True, default=None)
-    t_datetime = Column(PreciseTimestamp(), nullable=True, default=None)
+class TraitFloat(Base):
+    """Event float traits."""
 
-    event_id = Column(Integer, ForeignKey('event.id'))
-    event = relationship("Event", backref=backref('traits', order_by=id))
+    __tablename__ = 'trait_float'
+    __table_args__ = (
+        Index('ix_trait_float_event_id_key', 'event_id', 'key'),
+    )
+    event_id = Column(Integer, ForeignKey('event.id'), primary_key=True)
+    key = Column(Integer, primary_key=True)
+    value = Column(Float(53))
 
-    _value_map = {api_models.Trait.TEXT_TYPE: 't_string',
-                  api_models.Trait.FLOAT_TYPE: 't_float',
-                  api_models.Trait.INT_TYPE: 't_int',
-                  api_models.Trait.DATETIME_TYPE: 't_datetime'}
 
-    def __init__(self, trait_type, event, t_string=None,
-                 t_float=None, t_int=None, t_datetime=None):
-        self.trait_type = trait_type
-        self.t_string = t_string
-        self.t_float = t_float
-        self.t_int = t_int
-        self.t_datetime = t_datetime
-        self.event = event
+class TraitDatetime(Base):
+    """Event datetime traits."""
 
-    def get_value(self):
-        if self.trait_type is None:
-            dtype = None
-        else:
-            dtype = self.trait_type.data_type
-
-        if dtype == api_models.Trait.INT_TYPE:
-            return self.t_int
-        if dtype == api_models.Trait.FLOAT_TYPE:
-            return self.t_float
-        if dtype == api_models.Trait.DATETIME_TYPE:
-            return self.t_datetime
-        if dtype == api_models.Trait.TEXT_TYPE:
-            return self.t_string
-
-        return None
-
-    def __repr__(self):
-        name = self.trait_type.desc if self.trait_type else None
-        data_type = (self.trait_type.data_type if self.trait_type else
-                     api_models.Trait.NONE_TYPE)
-
-        return "<Trait(%s) %d=%s/%s/%s/%s on %s>" % (name,
-                                                     data_type,
-                                                     self.t_string,
-                                                     self.t_float,
-                                                     self.t_int,
-                                                     self.t_datetime,
-                                                     self.event)
+    __tablename__ = 'trait_datetime'
+    __table_args__ = (
+        Index('ix_trait_datetime_event_id_key', 'event_id', 'key'),
+    )
+    event_id = Column(Integer, ForeignKey('event.id'), primary_key=True)
+    key = Column(Integer, primary_key=True)
+    value = Column(PreciseTimestamp())
