@@ -19,8 +19,8 @@ import uuid
 
 from ceilometerclient.v2 import alarms
 import eventlet
-from oslo.config import fixture as fixture_config
-from oslo.utils import timeutils
+from oslo_config import fixture as fixture_config
+from oslo_utils import timeutils
 import six
 
 from ceilometer.alarm import rpc as rpc_alarm
@@ -67,6 +67,7 @@ class TestRPCAlarmNotifier(tests_base.BaseTestCase):
                 'project_id': 'snafu',
                 'period': 60,
                 'alarm_id': str(uuid.uuid4()),
+                'severity': 'critical',
                 'matching_metadata':{'resource_id':
                                      'my_instance'}
             }),
@@ -83,6 +84,7 @@ class TestRPCAlarmNotifier(tests_base.BaseTestCase):
                 'project_id': 'snafu',
                 'period': 300,
                 'alarm_id': str(uuid.uuid4()),
+                'severity': 'critical',
                 'matching_metadata':{'metadata.user_metadata.AS':
                                      'my_group'}
             }),
@@ -107,6 +109,10 @@ class TestRPCAlarmNotifier(tests_base.BaseTestCase):
             actions = getattr(a, models.Alarm.ALARM_ACTIONS_MAP[a.state])
             self.assertEqual(self.alarms[i].alarm_id,
                              self.notifier_server.notified[i]["alarm_id"])
+            self.assertEqual(self.alarms[i].name,
+                             self.notifier_server.notified[i]["alarm_name"])
+            self.assertEqual(self.alarms[i].severity,
+                             self.notifier_server.notified[i]["severity"])
             self.assertEqual(actions,
                              self.notifier_server.notified[i]["actions"])
             self.assertEqual(previous[i],
