@@ -1,4 +1,3 @@
-# -*- encoding: utf-8 -*-
 #
 # Copyright Ericsson AB 2014. All rights reserved
 #
@@ -33,5 +32,8 @@ class TestCapabilitiesController(tests_api.FunctionalTest,
 
     def test_capabilities(self):
         data = self.get_json(self.url)
+        # check that capabilities data contains both 'api' and 'storage' fields
         self.assertIsNotNone(data)
         self.assertNotEqual({}, data)
+        self.assertIn('api', data)
+        self.assertIn('storage', data)
