@@ -1,8 +1,5 @@
-# -*- encoding: utf-8 -*-
 #
-# Copyright © 2012 New Dream Network, LLC (DreamHost)
-#
-# Author: Doug Hellmann <doug.hellmann@dreamhost.com>
+# Copyright 2012 New Dream Network, LLC (DreamHost)
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -19,23 +16,16 @@
 """
 
 import datetime
-import logging
 
 import mock
-import testscenarios
+from oslo_utils import timeutils
 
-from ceilometer.openstack.common import timeutils
 from ceilometer.storage import models
-from ceilometer.tests.api.v2 import FunctionalTest
+from ceilometer.tests.api import v2
 from ceilometer.tests import db as tests_db
 
 
-load_tests = testscenarios.load_tests_apply_scenarios
-
-LOG = logging.getLogger(__name__)
-
-
-class TestComputeDurationByResource(FunctionalTest,
+class TestComputeDurationByResource(v2.FunctionalTest,
                                     tests_db.MixinTestsWithBackendScenarios):
 
     def setUp(self):
@@ -57,13 +47,14 @@ class TestComputeDurationByResource(FunctionalTest,
         self.late2 = datetime.datetime(2012, 8, 29, 19, 0)
 
     def _patch_get_interval(self, start, end):
-        def get_interval(event_filter, period, groupby, aggregate):
-            assert event_filter.start
-            assert event_filter.end
-            if (event_filter.start > end or event_filter.end < start):
+        def get_interval(sample_filter, period, groupby, aggregate):
+            self.assertIsNotNone(sample_filter.start_timestamp)
+            self.assertIsNotNone(sample_filter.end_timestamp)
+            if (sample_filter.start_timestamp > end or
+                    sample_filter.end_timestamp < start):
                 return []
-            duration_start = max(event_filter.start, start)
-            duration_end = min(event_filter.end, end)
+            duration_start = max(sample_filter.start_timestamp, start)
+            duration_end = min(sample_filter.end_timestamp, end)
             duration = timeutils.delta_seconds(duration_start, duration_end)
             return [
                 models.Statistics(
