@@ -16,10 +16,9 @@
 
 import datetime
 
-from oslo.utils import timeutils
 import webtest.app
 
-from ceilometer.storage import models
+from ceilometer.event.storage import models
 from ceilometer.tests.api import v2
 from ceilometer.tests import db as tests_db
 
@@ -36,6 +35,7 @@ class EventTestBase(v2.FunctionalTest,
     def _generate_models(self):
         event_models = []
         base = 0
+        self.s_time = datetime.datetime(2013, 12, 31, 5, 0)
         self.trait_time = datetime.datetime(2013, 12, 31, 5, 0)
         for event_type in ['Foo', 'Bar', 'Zoo']:
             trait_models = [models.Trait(name, type, value)
@@ -58,10 +58,11 @@ class EventTestBase(v2.FunctionalTest,
                 models.Event(message_id=str(base),
                              event_type=event_type,
                              generated=self.trait_time,
-                             traits=trait_models))
+                             traits=trait_models,
+                             raw={'status': {'nested': 'started'}}))
             base += 100
             self.trait_time += datetime.timedelta(days=1)
-        self.conn.record_events(event_models)
+        self.event_conn.record_events(event_models)
 
 
 class TestEventTypeAPI(EventTestBase):
@@ -71,7 +72,7 @@ class TestEventTypeAPI(EventTestBase):
     def test_event_types(self):
         data = self.get_json(self.PATH, headers=headers)
         for event_type in ['Foo', 'Bar', 'Zoo']:
-            self.assertTrue(event_type in data)
+            self.assertIn(event_type, data)
 
 
 class TestTraitAPI(EventTestBase):
@@ -130,24 +131,22 @@ class TestTraitAPI(EventTestBase):
 class TestEventAPI(EventTestBase):
 
     PATH = '/events'
-    START_TRAIT_TIME = datetime.datetime(2013, 12, 31, 5, 0)
 
     def test_get_events(self):
         data = self.get_json(self.PATH, headers=headers)
         self.assertEqual(3, len(data))
         # We expect to get native UTC generated time back
-        trait_time = self.START_TRAIT_TIME
+        trait_time = self.s_time
         for event in data:
-            expected_generated = timeutils.strtime(
-                at=timeutils.normalize_time(trait_time),
-                fmt=timeutils._ISO8601_TIME_FORMAT)
-            self.assertTrue(event['event_type'] in ['Foo', 'Bar', 'Zoo'])
+            expected_generated = trait_time.isoformat()
+            self.assertIn(event['event_type'], ['Foo', 'Bar', 'Zoo'])
             self.assertEqual(4, len(event['traits']))
+            self.assertEqual({'status': {'nested': 'started'}}, event['raw']),
             self.assertEqual(expected_generated, event['generated'])
             for trait_name in ['trait_A', 'trait_B',
                                'trait_C', 'trait_D']:
-                self.assertTrue(trait_name in map(lambda x: x['name'],
-                                                  event['traits']))
+                self.assertIn(trait_name, map(lambda x: x['name'],
+                              event['traits']))
             trait_time += datetime.timedelta(days=1)
 
     def test_get_event_by_message_id(self):
@@ -180,6 +179,34 @@ class TestEventAPI(EventTestBase):
                                  'value': 'Foo'}])
         self.assertEqual(1, len(data))
 
+    def test_get_events_filter_trait_no_type(self):
+        data = self.get_json(self.PATH, headers=headers,
+                             q=[{'field': 'trait_A',
+                                 'value': 'my_Foo_text'}])
+        self.assertEqual(1, len(data))
+        self.assertEqual('Foo', data[0]['event_type'])
+
+    def test_get_events_filter_trait_empty_type(self):
+        return
+        data = self.get_json(self.PATH, headers=headers,
+                             q=[{'field': 'trait_A',
+                                 'value': 'my_Foo_text',
+                                 'type': ''}])
+        self.assertEqual(1, len(data))
+        self.assertEqual('Foo', data[0]['event_type'])
+
+    def test_get_events_filter_trait_invalid_type(self):
+        resp = self.get_json(self.PATH, headers=headers,
+                             q=[{'field': 'trait_A',
+                                 'value': 'my_Foo_text',
+                                 'type': 'whats-up'}],
+                             expect_errors=True)
+        self.assertEqual(400, resp.status_code)
+        self.assertEqual("The data type whats-up is not supported. The "
+                         "supported data type list is: [\'integer\', "
+                         "\'float\', \'string\', \'datetime\']",
+                         resp.json['error_message']['faultstring'])
+
     def test_get_events_filter_text_trait(self):
         data = self.get_json(self.PATH, headers=headers,
                              q=[{'field': 'trait_A',
@@ -247,6 +274,16 @@ class TestEventAPI(EventTestBase):
 
         self.assertEqual(0, len(data))
 
+    def test_get_events_multiple_filters_same_field_different_values(self):
+        data = self.get_json(self.PATH, headers=headers,
+                             q=[{'field': 'trait_A',
+                                 'value': 'my_Foo_text',
+                                 'type': 'string'},
+                                {'field': 'trait_A',
+                                 'value': 'my_Bar_text',
+                                 'type': 'string'}])
+        self.assertEqual(0, len(data))
+
     def test_get_events_not_filters(self):
         data = self.get_json(self.PATH, headers=headers,
                              q=[])
@@ -410,4 +447,4 @@ class TestEventAPI(EventTestBase):
                           q=[{'field': 'trait_B',
                               'value': '1',
                               'type': 'integer',
-                              'op': 'el'}])
\ No newline at end of file
+                              'op': 'el'}])
