@@ -2,9 +2,6 @@
 # Copyright 2012 New Dream Network, LLC (DreamHost)
 # Copyright 2013 eNovance
 #
-# Author: Doug Hellmann <doug.hellmann@dreamhost.com>
-#         Julien Danjou <julien@danjou.info>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -622,7 +619,7 @@ class TestNotifications(base.BaseTestCase):
     def _verify_user_metadata(self, metadata):
         self.assertIn('user_metadata', metadata)
         user_meta = metadata['user_metadata']
-        self.assertEqual(user_meta.get('server_group'), 'Group_A')
+        self.assertEqual('Group_A', user_meta.get('server_group'))
         self.assertNotIn('AutoScalingGroupName', user_meta)
         self.assertIn('foo_bar', user_meta)
         self.assertNotIn('foo.bar', user_meta)
