@@ -17,7 +17,7 @@ Tests for VMware Vsphere inspector.
 """
 
 import mock
-from oslo.vmware import api
+from oslo_vmware import api
 from oslotest import base
 
 from ceilometer.compute.virt import inspector as virt_inspector
@@ -29,7 +29,7 @@ class TestVsphereInspection(base.BaseTestCase):
     def setUp(self):
         api_session = api.VMwareAPISession("test_server", "test_user",
                                            "test_password", 0, None,
-                                           create_session=False)
+                                           create_session=False, port=7443)
         vsphere_inspector.get_api_session = mock.Mock(
             return_value=api_session)
         self._inspector = vsphere_inspector.VsphereInspector()
@@ -100,7 +100,7 @@ class TestVsphereInspection(base.BaseTestCase):
         def query_stat_side_effect(vm_moid, counter_id, duration):
             # assert inputs
             self.assertEqual(test_vm_moid, vm_moid)
-            self.assertTrue(counter_id in counter_id_to_stats_map)
+            self.assertIn(counter_id, counter_id_to_stats_map)
             return counter_id_to_stats_map[counter_id]
 
         # configure vsphere operations mock with the test data
@@ -144,7 +144,7 @@ class TestVsphereInspection(base.BaseTestCase):
         def query_stat_side_effect(vm_moid, counter_id, duration):
             # assert inputs
             self.assertEqual(test_vm_moid, vm_moid)
-            self.assertTrue(counter_id in counter_id_to_stats_map)
+            self.assertIn(counter_id, counter_id_to_stats_map)
             return counter_id_to_stats_map[counter_id]
 
         # configure vsphere operations mock with the test data
