@@ -1,9 +1,6 @@
 #
 # Copyright 2012 Red Hat Inc.
 #
-# Author: Eoghan Glynn <eglynn@redhat.com>
-# Author: Julien danjou <julien@danjou.info>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -94,7 +91,7 @@ class TestNotification(base.BaseTestCase):
 
     def _verify_common_counter(self, c, name, volume):
         self.assertIsNotNone(c)
-        self.assertEqual(c.name, name)
+        self.assertEqual(name, c.name)
         self.assertEqual(fake_uuid('c'), c.resource_id)
         self.assertEqual(NOW, c.timestamp)
         self.assertEqual(volume, c.volume)
