@@ -1,7 +1,5 @@
 # Copyright 2014 Intel Corp.
 #
-# Author: Zhai Edwin <edwin.zhai@intel.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -15,7 +13,7 @@
 # under the License.
 
 import mock
-from oslo.config import cfg
+from oslo_config import cfg
 
 from ceilometer.ipmi.pollsters import sensor
 from ceilometer.tests.ipmi.notifications import ipmi_test_data
@@ -51,10 +49,6 @@ class TestTemperatureSensorPollster(base.TestPollsterBase):
     def fake_sensor_data(self, sensor_type):
         return TEMPERATURE_SENSOR_DATA
 
-    def fake_data(self):
-        # No use for Sensor test
-        return None
-
     def make_pollster(self):
         return sensor.TemperatureSensorPollster()
 
@@ -70,10 +64,6 @@ class TestMissingSensorData(base.TestPollsterBase):
     def fake_sensor_data(self, sensor_type):
         return MISSING_SENSOR_DATA
 
-    def fake_data(self):
-        # No use for Sensor test
-        return None
-
     def make_pollster(self):
         return sensor.TemperatureSensorPollster()
 
@@ -88,10 +78,6 @@ class TestMalformedSensorData(base.TestPollsterBase):
     def fake_sensor_data(self, sensor_type):
         return MALFORMED_SENSOR_DATA
 
-    def fake_data(self):
-        # No use for Sensor test
-        return None
-
     def make_pollster(self):
         return sensor.TemperatureSensorPollster()
 
@@ -106,10 +92,6 @@ class TestMissingSensorId(base.TestPollsterBase):
     def fake_sensor_data(self, sensor_type):
         return MISSING_ID_SENSOR_DATA
 
-    def fake_data(self):
-        # No use for Sensor test
-        return None
-
     def make_pollster(self):
         return sensor.TemperatureSensorPollster()
 
@@ -124,10 +106,6 @@ class TestFanSensorPollster(base.TestPollsterBase):
     def fake_sensor_data(self, sensor_type):
         return FAN_SENSOR_DATA
 
-    def fake_data(self):
-        # No use for Sensor test
-        return None
-
     def make_pollster(self):
         return sensor.FanSensorPollster()
 
@@ -143,10 +121,6 @@ class TestCurrentSensorPollster(base.TestPollsterBase):
     def fake_sensor_data(self, sensor_type):
         return CURRENT_SENSOR_DATA
 
-    def fake_data(self):
-        # No use for Sensor test
-        return None
-
     def make_pollster(self):
         return sensor.CurrentSensorPollster()
 
@@ -162,10 +136,6 @@ class TestVoltageSensorPollster(base.TestPollsterBase):
     def fake_sensor_data(self, sensor_type):
         return VOLTAGE_SENSOR_DATA
 
-    def fake_data(self):
-        # No use for Sensor test
-        return None
-
     def make_pollster(self):
         return sensor.VoltageSensorPollster()
 
