@@ -1,8 +1,6 @@
 #
 # Copyright 2014 Cisco Systems,Inc.
 #
-# Author: Pradeep Kilambi <pkilambi@cisco.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -16,14 +14,14 @@
 # under the License.
 
 import mock
+from oslo_context import context
 from oslotest import base
 from oslotest import mockpatch
 
-from ceilometer.central import manager
-from ceilometer.central import plugin
+from ceilometer.agent import manager
+from ceilometer.agent import plugin_base
 from ceilometer.network.services import discovery
 from ceilometer.network.services import lbaas
-from ceilometer.openstack.common import context
 
 
 class _BaseTestLBPollster(base.BaseTestCase):
@@ -34,9 +32,9 @@ class _BaseTestLBPollster(base.BaseTestCase):
         self.addCleanup(mock.patch.stopall)
         self.context = context.get_admin_context()
         self.manager = manager.AgentManager()
-        plugin._get_keystone = mock.Mock()
-        plugin._get_keystone.service_catalog.get_endpoints = mock.MagicMock(
-            return_value={'network': mock.ANY})
+        plugin_base._get_keystone = mock.Mock()
+        plugin_base._get_keystone.service_catalog.get_endpoints = (
+            mock.MagicMock(return_value={'network': mock.ANY}))
 
 
 class TestLBPoolPollster(_BaseTestLBPollster):
@@ -157,9 +155,9 @@ class TestLBPoolPollster(_BaseTestLBPollster):
         self.assertEqual(4, len(discovered_pools))
         for pool in self.fake_get_pools():
             if pool['status'] == 'error':
-                self.assertTrue(pool not in discovered_pools)
+                self.assertNotIn(pool, discovered_pools)
             else:
-                self.assertTrue(pool in discovered_pools)
+                self.assertIn(pool, discovered_pools)
 
 
 class TestLBVipPollster(_BaseTestLBPollster):
@@ -280,9 +278,9 @@ class TestLBVipPollster(_BaseTestLBPollster):
         self.assertEqual(4, len(discovered_vips))
         for pool in self.fake_get_vips():
             if pool['status'] == 'error':
-                self.assertTrue(pool not in discovered_vips)
+                self.assertNotIn(pool, discovered_vips)
             else:
-                self.assertTrue(pool in discovered_vips)
+                self.assertIn(pool, discovered_vips)
 
 
 class TestLBMemberPollster(_BaseTestLBPollster):
@@ -374,9 +372,9 @@ class TestLBMemberPollster(_BaseTestLBPollster):
         self.assertEqual(4, len(discovered_members))
         for pool in self.fake_get_members():
             if pool['status'] == 'error':
-                self.assertTrue(pool not in discovered_members)
+                self.assertNotIn(pool, discovered_members)
             else:
-                self.assertTrue(pool in discovered_members)
+                self.assertIn(pool, discovered_members)
 
 
 class TestLBHealthProbePollster(_BaseTestLBPollster):
@@ -486,7 +484,7 @@ class TestLBStatsPollster(_BaseTestLBPollster):
     def test_lb_total_connections(self):
         self._check_get_samples(lbaas.LBTotalConnectionsPollster,
                                 'network.services.lb.total.connections',
-                                4L, 'gauge')
+                                4L, 'cumulative')
 
     def test_lb_active_connections(self):
         self._check_get_samples(lbaas.LBActiveConnectionsPollster,
