@@ -22,7 +22,7 @@ import datetime
 import traceback
 
 import mock
-from oslo.utils import timeutils
+from oslo_utils import timeutils
 from oslotest import base
 from oslotest import mockpatch
 import six
@@ -40,7 +40,8 @@ from ceilometer.transformer import conversions
 
 @six.add_metaclass(abc.ABCMeta)
 class BasePipelineTestCase(base.BaseTestCase):
-    def fake_tem_init(self):
+    @staticmethod
+    def fake_tem_init():
         """Fake a transformerManager for pipeline.
 
         The faked entry point setting is below:
@@ -77,7 +78,10 @@ class BasePipelineTestCase(base.BaseTestCase):
         return fake_drivers[url](url)
 
     class PublisherClassException(publisher.PublisherBase):
-        def publish_samples(self, ctxt, counters):
+        def publish_samples(self, ctxt, samples):
+            raise Exception()
+
+        def publish_events(self, ctxt, events):
             raise Exception()
 
     class TransformerClass(transformer.TransformerBase):
@@ -115,7 +119,8 @@ class BasePipelineTestCase(base.BaseTestCase):
             self.__class__.samples.append(counter)
 
     class TransformerClassException(object):
-        def handle_sample(self, ctxt, counter):
+        @staticmethod
+        def handle_sample(ctxt, counter):
             raise Exception()
 
     def setUp(self):
@@ -169,6 +174,10 @@ class BasePipelineTestCase(base.BaseTestCase):
     def _break_pipeline_cfg(self):
         """Break the pipeline config with a malformed element."""
 
+    @abc.abstractmethod
+    def _dup_pipeline_name_cfg(self):
+        """Break the pipeline config with duplicate pipeline name."""
+
     @abc.abstractmethod
     def _set_pipeline_cfg(self, field, value):
         """Set a field to a value in the pipeline config."""
@@ -193,7 +202,7 @@ class BasePipelineTestCase(base.BaseTestCase):
 
     def test_no_transformers(self):
         self._unset_pipeline_cfg('transformers')
-        self._exception_create_pipelinemanager()
+        pipeline.PipelineManager(self.pipeline_cfg, self.transformer_manager)
 
     def test_no_name(self):
         self._unset_pipeline_cfg('name')
@@ -296,6 +305,72 @@ class BasePipelineTestCase(base.BaseTestCase):
         self.assertEqual('a_update', getattr(publisher.samples[0], "name"))
         self.assertEqual('b_update', getattr(publisher.samples[1], "name"))
 
+    @mock.patch('ceilometer.pipeline.LOG')
+    def test_none_volume_counter(self, log):
+        self._set_pipeline_cfg('counters', ['empty_volume'])
+        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
+                                                    self.transformer_manager)
+        publisher = pipeline_manager.pipelines[0].publishers[0]
+
+        test_s = sample.Sample(
+            name='empty_volume',
+            type=self.test_counter.type,
+            volume=None,
+            unit=self.test_counter.unit,
+            user_id=self.test_counter.user_id,
+            project_id=self.test_counter.project_id,
+            resource_id=self.test_counter.resource_id,
+            timestamp=self.test_counter.timestamp,
+            resource_metadata=self.test_counter.resource_metadata,
+        )
+
+        with pipeline_manager.publisher(None) as p:
+            p([test_s])
+
+        log.warning.assert_called_with(
+            'metering data %(counter_name)s for %(resource_id)s '
+            '@ %(timestamp)s has no volume (volume: %(counter_volume)s), the '
+            'sample will be dropped'
+            % {'counter_name': test_s.name,
+               'resource_id': test_s.resource_id,
+               'timestamp': test_s.timestamp,
+               'counter_volume': test_s.volume})
+
+        self.assertEqual(0, len(publisher.samples))
+
+    @mock.patch('ceilometer.pipeline.LOG')
+    def test_fake_volume_counter(self, log):
+        self._set_pipeline_cfg('counters', ['fake_volume'])
+        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
+                                                    self.transformer_manager)
+        publisher = pipeline_manager.pipelines[0].publishers[0]
+
+        test_s = sample.Sample(
+            name='fake_volume',
+            type=self.test_counter.type,
+            volume='fake_value',
+            unit=self.test_counter.unit,
+            user_id=self.test_counter.user_id,
+            project_id=self.test_counter.project_id,
+            resource_id=self.test_counter.resource_id,
+            timestamp=self.test_counter.timestamp,
+            resource_metadata=self.test_counter.resource_metadata,
+        )
+
+        with pipeline_manager.publisher(None) as p:
+            p([test_s])
+
+        log.warning.assert_called_with(
+            'metering data %(counter_name)s for %(resource_id)s '
+            '@ %(timestamp)s has volume which is not a number '
+            '(volume: %(counter_volume)s), the sample will be dropped'
+            % {'counter_name': test_s.name,
+               'resource_id': test_s.resource_id,
+               'timestamp': test_s.timestamp,
+               'counter_volume': test_s.volume})
+
+        self.assertEqual(0, len(publisher.samples))
+
     def test_counter_dont_match(self):
         counter_cfg = ['nomatch']
         self._set_pipeline_cfg('counters', counter_cfg)
@@ -663,16 +738,16 @@ class BasePipelineTestCase(base.BaseTestCase):
                                                     self.transformer_manager)
         pipe = pipeline_manager.pipelines[0]
 
-        pipe.publish_sample(None, self.test_counter)
+        pipe.publish_data(None, self.test_counter)
         publisher = pipeline_manager.pipelines[0].publishers[0]
         self.assertEqual(0, len(publisher.samples))
         pipe.flush(None)
         self.assertEqual(0, len(publisher.samples))
-        pipe.publish_sample(None, self.test_counter)
+        pipe.publish_data(None, self.test_counter)
         pipe.flush(None)
         self.assertEqual(0, len(publisher.samples))
         for i in range(CACHE_SIZE - 2):
-            pipe.publish_sample(None, self.test_counter)
+            pipe.publish_data(None, self.test_counter)
         pipe.flush(None)
         self.assertEqual(CACHE_SIZE, len(publisher.samples))
         self.assertEqual('a_update_new', getattr(publisher.samples[0], 'name'))
@@ -735,7 +810,7 @@ class BasePipelineTestCase(base.BaseTestCase):
         pipe = pipeline_manager.pipelines[0]
 
         publisher = pipe.publishers[0]
-        pipe.publish_sample(None, self.test_counter)
+        pipe.publish_data(None, self.test_counter)
         self.assertEqual(0, len(publisher.samples))
         pipe.flush(None)
         self.assertEqual(1, len(publisher.samples))
@@ -812,7 +887,7 @@ class BasePipelineTestCase(base.BaseTestCase):
                                                     self.transformer_manager)
         pipe = pipeline_manager.pipelines[0]
 
-        pipe.publish_samples(None, counters)
+        pipe.publish_data(None, counters)
         publisher = pipeline_manager.pipelines[0].publishers[0]
         self.assertEqual(1, len(publisher.samples))
         pipe.flush(None)
@@ -866,14 +941,14 @@ class BasePipelineTestCase(base.BaseTestCase):
                                                     self.transformer_manager)
         pipe = pipeline_manager.pipelines[0]
 
-        pipe.publish_samples(None, counters)
+        pipe.publish_data(None, counters)
         publisher = pipeline_manager.pipelines[0].publishers[0]
         self.assertEqual(2, len(publisher.samples))
-        core_temp = publisher.samples[1]
+        core_temp = publisher.samples[0]
         self.assertEqual('core_temperature', getattr(core_temp, 'name'))
         self.assertEqual('°F', getattr(core_temp, 'unit'))
         self.assertEqual(96.8, getattr(core_temp, 'volume'))
-        amb_temp = publisher.samples[0]
+        amb_temp = publisher.samples[1]
         self.assertEqual('ambient_temperature', getattr(amb_temp, 'name'))
         self.assertEqual('°F', getattr(amb_temp, 'unit'))
         self.assertEqual(88.8, getattr(amb_temp, 'volume'))
@@ -956,7 +1031,7 @@ class BasePipelineTestCase(base.BaseTestCase):
                                                     self.transformer_manager)
         pipe = pipeline_manager.pipelines[0]
 
-        pipe.publish_samples(None, counters)
+        pipe.publish_data(None, counters)
         publisher = pipeline_manager.pipelines[0].publishers[0]
         self.assertEqual(2, len(publisher.samples))
         pipe.flush(None)
@@ -1041,7 +1116,7 @@ class BasePipelineTestCase(base.BaseTestCase):
                                                     self.transformer_manager)
         pipe = pipeline_manager.pipelines[0]
 
-        pipe.publish_samples(None, counters)
+        pipe.publish_data(None, counters)
         publisher = pipeline_manager.pipelines[0].publishers[0]
         self.assertEqual(0, len(publisher.samples))
         pipe.flush(None)
@@ -1084,7 +1159,7 @@ class BasePipelineTestCase(base.BaseTestCase):
                 )
                 counters.append(s)
 
-        pipe.publish_samples(None, counters)
+        pipe.publish_data(None, counters)
         publisher = pipe.publishers[0]
         self.assertEqual(2, len(publisher.samples))
         pipe.flush(None)
@@ -1213,7 +1288,7 @@ class BasePipelineTestCase(base.BaseTestCase):
                                                     self.transformer_manager)
         pipe = pipeline_manager.pipelines[0]
 
-        pipe.publish_samples(None, counters)
+        pipe.publish_data(None, counters)
         pipe.flush(None)
         publisher = pipeline_manager.pipelines[0].publishers[0]
         self.assertEqual(expected_length, len(publisher.samples))
@@ -1249,21 +1324,12 @@ class BasePipelineTestCase(base.BaseTestCase):
                                                     self.transformer_manager)
         pipe = pipeline_manager.pipelines[0]
 
-        pipe.publish_samples(None, counters)
+        pipe.publish_data(None, counters)
         pipe.flush(None)
         publisher = pipeline_manager.pipelines[0].publishers[0]
         actual = sorted(s.volume for s in publisher.samples)
         self.assertEqual([2.0, 3.0, 6.0], actual)
 
-    def test_aggregator_input_validation(self):
-        aggregator = conversions.AggregatorTransformer("1", "15", None,
-                                                       None, None)
-        self.assertEqual(1, aggregator.size)
-        self.assertEqual(15, aggregator.retention_time)
-
-        self.assertRaises(ValueError, conversions.AggregatorTransformer,
-                          "abc", "cde", None, None, None)
-
     def test_aggregator_metadata(self):
         for conf, expected_version in [('last', '2.0'), ('first', '1.0')]:
             samples = self._do_test_aggregator({
@@ -1454,12 +1520,12 @@ class BasePipelineTestCase(base.BaseTestCase):
                                                     self.transformer_manager)
         pipe = pipeline_manager.pipelines[0]
 
-        pipe.publish_samples(None, [counters[0]])
+        pipe.publish_data(None, [counters[0]])
         pipe.flush(None)
         publisher = pipe.publishers[0]
         self.assertEqual(0, len(publisher.samples))
 
-        pipe.publish_samples(None, [counters[1]])
+        pipe.publish_data(None, [counters[1]])
         pipe.flush(None)
         publisher = pipe.publishers[0]
         self.assertEqual(2, len(publisher.samples))
@@ -1492,7 +1558,7 @@ class BasePipelineTestCase(base.BaseTestCase):
                                                     self.transformer_manager)
         pipe = pipeline_manager.pipelines[0]
 
-        pipe.publish_samples(None, counters)
+        pipe.publish_data(None, counters)
         pipe.flush(None)
         publisher = pipeline_manager.pipelines[0].publishers[0]
         self.assertEqual(0, len(publisher.samples))
@@ -1540,12 +1606,12 @@ class BasePipelineTestCase(base.BaseTestCase):
                                                     self.transformer_manager)
         pipe = pipeline_manager.pipelines[0]
 
-        pipe.publish_samples(None, [counters[0]])
+        pipe.publish_data(None, [counters[0]])
         pipe.flush(None)
         publisher = pipe.publishers[0]
         self.assertEqual(0, len(publisher.samples))
 
-        pipe.publish_samples(None, [counters[1]])
+        pipe.publish_data(None, [counters[1]])
         pipe.flush(None)
         publisher = pipe.publishers[0]
 
@@ -1629,7 +1695,7 @@ class BasePipelineTestCase(base.BaseTestCase):
                                                     self.transformer_manager)
         pipe = pipeline_manager.pipelines[0]
 
-        pipe.publish_samples(None, counters)
+        pipe.publish_data(None, counters)
         publisher = pipeline_manager.pipelines[0].publishers[0]
         expected_len = len(test_resources) * len(expected)
         self.assertEqual(0, len(publisher.samples))
@@ -1750,7 +1816,7 @@ class BasePipelineTestCase(base.BaseTestCase):
                                                     self.transformer_manager)
         pipe = pipeline_manager.pipelines[0]
 
-        pipe.publish_samples(None, [counter])
+        pipe.publish_data(None, [counter])
         publisher = pipeline_manager.pipelines[0].publishers[0]
         self.assertEqual(0, len(publisher.samples))
         pipe.flush(None)
@@ -1761,7 +1827,7 @@ class BasePipelineTestCase(base.BaseTestCase):
         self.assertEqual(1, len(publisher.samples))
 
         counter.volume = 2048.0
-        pipe.publish_samples(None, [counter])
+        pipe.publish_data(None, [counter])
         pipe.flush(None)
         self.assertEqual(2, len(publisher.samples))
         self.assertEqual(2050.0, publisher.samples[1].volume)
@@ -1783,3 +1849,7 @@ class BasePipelineTestCase(base.BaseTestCase):
         pipe.flush(None)
         publisher = pipeline_manager.pipelines[0].publishers[0]
         self.assertEqual(0, len(publisher.samples))
+
+    def test_unique_pipeline_names(self):
+        self._dup_pipeline_name_cfg()
+        self._exception_create_pipelinemanager()
