@@ -1,9 +1,6 @@
 #
 # Copyright 2012, 2013 Dell Inc.
 #
-# Author: Stas Maksimov <Stanislav_M@dell.com>
-# Author: Shengjie Min <Shengjie_Min@dell.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -26,6 +23,7 @@
 import mock
 
 from ceilometer.alarm.storage import impl_hbase as hbase_alarm
+from ceilometer.event.storage import impl_hbase as hbase_event
 from ceilometer.storage import impl_hbase as hbase
 from ceilometer.tests import base as test_base
 from ceilometer.tests import db as tests_db
@@ -68,7 +66,6 @@ class CapabilitiesTest(test_base.BaseTestCase):
                                     'metadata': True,
                                     'complex': False}},
             'samples': {'pagination': False,
-                        'groupby': False,
                         'query': {'simple': True,
                                   'metadata': True,
                                   'complex': False}},
@@ -87,7 +84,6 @@ class CapabilitiesTest(test_base.BaseTestCase):
                                                'stddev': False,
                                                'cardinality': False}}
                            },
-            'events': {'query': {'simple': True}},
         }
 
         actual_capabilities = hbase.Connection.get_capabilities()
@@ -104,6 +100,14 @@ class CapabilitiesTest(test_base.BaseTestCase):
         actual_capabilities = hbase_alarm.Connection.get_capabilities()
         self.assertEqual(expected_capabilities, actual_capabilities)
 
+    def test_event_capabilities(self):
+        expected_capabilities = {
+            'events': {'query': {'simple': True}},
+        }
+
+        actual_capabilities = hbase_event.Connection.get_capabilities()
+        self.assertEqual(expected_capabilities, actual_capabilities)
+
     def test_storage_capabilities(self):
         expected_capabilities = {
             'storage': {'production_ready': True},
