@@ -1,8 +1,6 @@
 #
 # Copyright 2012 New Dream Network, LLC (DreamHost)
 #
-# Author: Doug Hellmann <doug.hellmann@dreamhost.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -19,16 +17,16 @@ import socket
 
 import mock
 import msgpack
-from oslo.config import fixture as fixture_config
 import oslo.messaging
-from oslo.utils import timeutils
+from oslo_config import fixture as fixture_config
+from oslo_context import context
+from oslo_utils import timeutils
 from oslotest import mockpatch
 from stevedore import extension
 
 from ceilometer import collector
 from ceilometer import dispatcher
 from ceilometer import messaging
-from ceilometer.openstack.common import context
 from ceilometer.publisher import utils
 from ceilometer import sample
 from ceilometer.tests import base as tests_base
@@ -38,7 +36,7 @@ class FakeException(Exception):
     pass
 
 
-class FakeConnection():
+class FakeConnection(object):
     def create_worker(self, topic, proxy, pool_name):
         pass
 
@@ -49,7 +47,7 @@ class TestCollector(tests_base.BaseTestCase):
         self.CONF = self.useFixture(fixture_config.Config()).conf
         self.CONF.import_opt("connection", "oslo.db.options", group="database")
         self.CONF.set_override("connection", "log://", group='database')
-        self.CONF.set_override('metering_secret', 'not-so-secret',
+        self.CONF.set_override('telemetry_secret', 'not-so-secret',
                                group='publisher')
         self._setup_messaging()
 
@@ -102,7 +100,7 @@ class TestCollector(tests_base.BaseTestCase):
         plugin = mock.MagicMock()
         fake_dispatcher = extension.ExtensionManager.make_test_instance([
             extension.Extension('test', None, None, plugin,),
-        ])
+        ], propagate_map_exceptions=True)
         self.useFixture(mockpatch.Patch(
             'ceilometer.dispatcher.load_dispatcher_manager',
             return_value=fake_dispatcher))
@@ -143,14 +141,27 @@ class TestCollector(tests_base.BaseTestCase):
 
         udp_socket = self._make_fake_socket(self.counter)
 
-        with mock.patch('socket.socket', return_value=udp_socket):
+        with mock.patch('socket.socket') as mock_socket:
+            mock_socket.return_value = udp_socket
             self.srv.start()
+            mock_socket.assert_called_with(socket.AF_INET, socket.SOCK_DGRAM)
 
         self._verify_udp_socket(udp_socket)
 
         mock_dispatcher.record_metering_data.assert_called_once_with(
             self.counter)
 
+    def test_udp_socket_ipv6(self):
+        self._setup_messaging(False)
+        self.CONF.set_override('udp_address', '::1', group='collector')
+        self._setup_fake_dispatcher()
+        sock = self._make_fake_socket('data')
+
+        with mock.patch.object(socket, 'socket') as mock_socket:
+            mock_socket.return_value = sock
+            self.srv.start()
+            mock_socket.assert_called_with(socket.AF_INET6, socket.SOCK_DGRAM)
+
     def test_udp_receive_storage_error(self):
         self._setup_messaging(False)
         mock_dispatcher = self._setup_fake_dispatcher()
@@ -232,25 +243,62 @@ class TestCollector(tests_base.BaseTestCase):
         mylog.info.assert_called_once_with(
             'metering data test for test_run_tasks: 1')
 
-    @mock.patch.object(oslo.messaging.MessageHandlingServer, 'start')
-    @mock.patch.object(collector.CollectorService, 'start_udp')
-    def test_collector_requeue(self, udp_start, rpc_start):
+    def _test_collector_requeue(self, listener):
+
+        mock_dispatcher = self._setup_fake_dispatcher()
+        self.srv.dispatcher_manager = dispatcher.load_dispatcher_manager()
+        mock_dispatcher.record_metering_data.side_effect = Exception('boom')
+        mock_dispatcher.record_events.side_effect = Exception('boom')
+
+        self.srv.start()
+        endp = getattr(self.srv, listener).dispatcher.endpoints[0]
+        ret = endp.sample({}, 'pub_id', 'event', {}, {})
+        self.assertEqual(oslo.messaging.NotificationResult.REQUEUE,
+                         ret)
+
+    @mock.patch.object(oslo.messaging.MessageHandlingServer, 'start',
+                       mock.Mock())
+    @mock.patch.object(collector.CollectorService, 'start_udp', mock.Mock())
+    def test_collector_sample_requeue(self):
         self.CONF.set_override('requeue_sample_on_dispatcher_error', True,
                                group='collector')
-        self.srv.start()
-        with mock.patch.object(self.srv.dispatcher_manager, 'map_method',
-                               side_effect=Exception('boom')):
-            ret = self.srv.sample({}, 'pub_id', 'event', {}, {})
-            self.assertEqual(oslo.messaging.NotificationResult.REQUEUE,
-                             ret)
+        self._test_collector_requeue('sample_listener')
 
-    @mock.patch.object(oslo.messaging.MessageHandlingServer, 'start')
-    @mock.patch.object(collector.CollectorService, 'start_udp')
-    def test_collector_no_requeue(self, udp_start, rpc_start):
+    @mock.patch.object(oslo.messaging.MessageHandlingServer, 'start',
+                       mock.Mock())
+    @mock.patch.object(collector.CollectorService, 'start_udp', mock.Mock())
+    def test_collector_event_requeue(self):
+        self.CONF.set_override('requeue_event_on_dispatcher_error', True,
+                               group='collector')
+        self.CONF.set_override('store_events', True, group='notification')
+        self._test_collector_requeue('event_listener')
+
+    def _test_collector_no_requeue(self, listener):
+        mock_dispatcher = self._setup_fake_dispatcher()
+        self.srv.dispatcher_manager = dispatcher.load_dispatcher_manager()
+        mock_dispatcher.record_metering_data.side_effect = (FakeException
+                                                            ('boom'))
+        mock_dispatcher.record_events.side_effect = (FakeException
+                                                     ('boom'))
+
+        self.srv.start()
+        endp = getattr(self.srv, listener).dispatcher.endpoints[0]
+        self.assertRaises(FakeException, endp.sample, {}, 'pub_id',
+                          'event', {}, {})
+
+    @mock.patch.object(oslo.messaging.MessageHandlingServer, 'start',
+                       mock.Mock())
+    @mock.patch.object(collector.CollectorService, 'start_udp', mock.Mock())
+    def test_collector_sample_no_requeue(self):
         self.CONF.set_override('requeue_sample_on_dispatcher_error', False,
                                group='collector')
-        self.srv.start()
-        with mock.patch.object(self.srv.dispatcher_manager, 'map_method',
-                               side_effect=FakeException('boom')):
-            self.assertRaises(FakeException, self.srv.sample, {}, 'pub_id',
-                              'event', {}, {})
+        self._test_collector_no_requeue('sample_listener')
+
+    @mock.patch.object(oslo.messaging.MessageHandlingServer, 'start',
+                       mock.Mock())
+    @mock.patch.object(collector.CollectorService, 'start_udp', mock.Mock())
+    def test_collector_event_no_requeue(self):
+        self.CONF.set_override('requeue_event_on_dispatcher_error', False,
+                               group='collector')
+        self.CONF.set_override('store_events', True, group='notification')
+        self._test_collector_no_requeue('event_listener')
