@@ -1,8 +1,6 @@
 #
 # Copyright 2014 Red Hat, Inc.
 #
-# Author: Nejc Saje <nsaje@redhat.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -16,8 +14,9 @@
 # under the License.
 
 import logging
+
 import mock
-from oslo.config import fixture as fixture_config
+from oslo_config import fixture as fixture_config
 import tooz.coordination
 
 from ceilometer import coordination
@@ -33,6 +32,9 @@ class MockToozCoordinator(object):
     def start(self):
         pass
 
+    def stop(self):
+        pass
+
     def heartbeat(self):
         pass
 
@@ -56,6 +58,9 @@ class MockToozCoordinator(object):
         }
         return MockAsyncResult(None)
 
+    def leave_group(self, group_id):
+        return MockAsyncResult(None)
+
     def get_members(self, group_id):
         if group_id not in self._groups:
             return MockAsyncError(
@@ -77,6 +82,21 @@ class MockToozCoordExceptionRaiser(MockToozCoordinator):
         raise tooz.coordination.ToozError('error')
 
 
+class MockToozCoordExceptionOnJoinRaiser(MockToozCoordinator):
+    def __init__(self, member_id, shared_storage, retry_count=None):
+        super(MockToozCoordExceptionOnJoinRaiser,
+              self).__init__(member_id, shared_storage)
+        self.tooz_error_count = retry_count
+        self.count = 0
+
+    def join_group(self, group_id, capabilities=b''):
+        if self.count == self.tooz_error_count:
+            return MockAsyncResult(None)
+        else:
+            self.count += 1
+            raise tooz.coordination.ToozError('error')
+
+
 class MockAsyncResult(tooz.coordination.CoordAsyncResult):
     def __init__(self, result):
         self.result = result
@@ -129,12 +149,14 @@ class TestPartitioning(base.BaseTestCase):
         self.shared_storage = {}
 
     def _get_new_started_coordinator(self, shared_storage, agent_id=None,
-                                     coordinator_cls=None):
+                                     coordinator_cls=None, retry_count=None):
         coordinator_cls = coordinator_cls or MockToozCoordinator
         self.CONF.set_override('backend_url', 'xxx://yyy',
                                group='coordination')
         with mock.patch('tooz.coordination.get_coordinator',
                         lambda _, member_id:
+                        coordinator_cls(member_id, shared_storage,
+                                        retry_count) if retry_count else
                         coordinator_cls(member_id, shared_storage)):
             pc = coordination.PartitionCoordinator(agent_id)
             pc.start()
@@ -161,17 +183,17 @@ class TestPartitioning(base.BaseTestCase):
                   dict(agent_id='agent2', group_id='group')]
         self._usage_simulation(*agents)
 
-        self.assertEqual(sorted(self.shared_storage.keys()), ['group'])
-        self.assertEqual(sorted(self.shared_storage['group'].keys()),
-                         ['agent1', 'agent2'])
+        self.assertEqual(['group'], sorted(self.shared_storage.keys()))
+        self.assertEqual(['agent1', 'agent2'],
+                         sorted(self.shared_storage['group'].keys()))
 
     def test_multiple_groups(self):
         agents = [dict(agent_id='agent1', group_id='group1'),
                   dict(agent_id='agent2', group_id='group2')]
         self._usage_simulation(*agents)
 
-        self.assertEqual(sorted(self.shared_storage.keys()), ['group1',
-                                                              'group2'])
+        self.assertEqual(['group1', 'group2'],
+                         sorted(self.shared_storage.keys()))
 
     def test_partitioning(self):
         all_resources = ['resource_%s' % i for i in range(1000)]
@@ -204,6 +226,20 @@ class TestPartitioning(base.BaseTestCase):
         for e in expected_errors:
             self.assertIn(e, self.str_handler.messages['error'])
 
+    def test_coordination_backend_connection_fail_on_join(self):
+        coord = self._get_new_started_coordinator(
+            {'group'}, 'agent1', MockToozCoordExceptionOnJoinRaiser,
+            retry_count=2)
+        with mock.patch('tooz.coordination.get_coordinator',
+                        return_value=MockToozCoordExceptionOnJoinRaiser):
+            coord.join_group(group_id='group')
+
+        expected_errors = ['Error joining partitioning group group,'
+                           ' re-trying',
+                           'Error joining partitioning group group,'
+                           ' re-trying']
+        self.assertEqual(expected_errors, self.str_handler.messages['error'])
+
     def test_reconnect(self):
         coord = self._get_new_started_coordinator({}, 'a',
                                                   MockToozCoordExceptionRaiser)
@@ -222,3 +258,23 @@ class TestPartitioning(base.BaseTestCase):
             coord.heartbeat()
         for e in expected_errors:
             self.assertNotIn(e, self.str_handler.messages['error'])
+
+    def test_group_id_none(self):
+        coord = self._get_new_started_coordinator({}, 'a')
+        self.assertTrue(coord._started)
+
+        with mock.patch.object(coord._coordinator, 'join_group') as mocked:
+            coord.join_group(None)
+            self.assertEqual(0, mocked.call_count)
+        with mock.patch.object(coord._coordinator, 'leave_group') as mocked:
+            coord.leave_group(None)
+            self.assertEqual(0, mocked.call_count)
+
+    def test_stop(self):
+        coord = self._get_new_started_coordinator({}, 'a')
+        self.assertTrue(coord._started)
+        coord.join_group("123")
+        coord.stop()
+        self.assertIsEmpty(coord._groups)
+        self.assertFalse(coord._started)
+        self.assertIsNone(coord._coordinator)
