@@ -1,8 +1,6 @@
 #
 # Copyright 2013 Red Hat, Inc
 #
-# Author: Eoghan Glynn <eglynn@redhat.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -18,10 +16,10 @@
 import collections
 import re
 
-from oslo.utils import timeutils
+from oslo_utils import timeutils
 import six
 
-from ceilometer.openstack.common.gettextutils import _
+from ceilometer.i18n import _
 from ceilometer.openstack.common import log
 from ceilometer import sample
 from ceilometer import transformer
@@ -169,6 +167,9 @@ class AggregatorTransformer(ScalingTransformer):
         self.counts = collections.defaultdict(int)
         self.size = int(size) if size else None
         self.retention_time = float(retention_time) if retention_time else None
+        if not (self.size or self.retention_time):
+            self.size = 1
+
         self.initial_timestamp = None
         self.aggregated_samples = 0
 
@@ -231,7 +232,7 @@ class AggregatorTransformer(ScalingTransformer):
         expired = (self.retention_time and
                    timeutils.is_older_than(self.initial_timestamp,
                                            self.retention_time))
-        full = self.aggregated_samples >= self.size
+        full = self.size and self.aggregated_samples >= self.size
         if full or expired:
             x = self.samples.values()
             # gauge aggregates need to be averages
